@@ -1,6 +1,6 @@
 package Perl::Dist::WiX::Asset::DistBase;
 
-use 5.010;
+use 5.008001;
 use Moose;
 use File::Spec::Functions qw( catdir catfile );
 use Params::Util qw ( _INSTANCE );
@@ -8,11 +8,8 @@ use Params::Util qw ( _INSTANCE );
 require URI;
 require File::Spec::Unix;
 
-our $VERSION = '1.250_100';
-$VERSION =~ s/_//ms;
-
-# This is a base class, so routines in here would be technically "unused".
-## no critic(ProhibitUnusedPrivateSubroutines)
+our $VERSION = '1.100';
+$VERSION = eval $VERSION; ## no critic (ProhibitStringyEval)
 
 sub _configure {
 	my $self    = shift;
@@ -21,8 +18,8 @@ sub _configure {
 
 	$self->_trace_line( 2, "Configuring $name...\n" );
 	$buildpl
-	  ? $self->_perl( 'Build.PL',    @{ $self->_get_buildpl_param() } )
-	  : $self->_perl( 'Makefile.PL', @{ $self->_get_makefilepl_param() } );
+	  ? $self->_perl( 'Build.PL',    @{ $self->_get_buildpl_param } )
+	  : $self->_perl( 'Makefile.PL', @{ $self->_get_makefilepl_param } );
 
 	return;
 } ## end sub _configure
@@ -35,7 +32,7 @@ sub _install_distribution {
 	$self->_trace_line( 1, "Building $name...\n" );
 	$buildpl ? $self->_build() : $self->_make();
 
-	if ( not $self->_get_force() ) {
+	unless ( $self->_get_force() ) {
 		$self->_trace_line( 2, "Testing $name...\n" );
 		$buildpl ? $self->_build('test') : $self->_make('test');
 	}
@@ -52,18 +49,11 @@ sub _name_to_module {
 	my $self = shift;
 	my $dist = shift;
 
-	if ( not defined $dist ) {
-		PDWiX::Parameter->throw(
-			parameter => 'dist',
-			where     => '::Asset::DistBase->_name_to_module',
-		);
-	}
-
 	$self->_trace_line( 3, "Trying to get module name out of $dist\n" );
 
 #<<<
 	my ( $module ) = $dist =~ m{\A  # Start the string...
-					[[:alpha:]/]*   # With a string of letters and slashes
+					[A-Za-z/]*      # With a string of letters and slashes
 					/               # followed by a forward slash. 
 					(.*?)           # Then capture all characters, non-greedily 
 					-\d*[.]         # up to a dash, a sequence of digits, and then a period.
@@ -78,19 +68,17 @@ sub _module_build_installed {
 	my $self      = shift;
 	my $image_dir = $self->_get_image_dir();
 
-	# Get all the directories to check.
+	my $perl_dir = catdir( $image_dir, 'perl' );
 	my @dirs = (
 		catdir( $image_dir, qw( perl vendor lib Module ) ),
 		catdir( $image_dir, qw( perl site lib Module ) ),
 		catdir( $image_dir, qw( perl lib Module ) ),
 	);
 
-	# Return if we find Module::Build.
 	foreach my $dir (@dirs) {
 		return 1 if -f catfile( $dir, 'Build.pm' );
 	}
 
-	# We did not find it, so return that fact now.
 	return 0;
 } ## end sub _module_build_installed
 
@@ -102,7 +90,7 @@ sub _abs_uri {
 
 	# Get the base path
 	my $cpan = _INSTANCE( $self->_get_cpan(), 'URI' );
-	if ( not $cpan ) {
+	unless ($cpan) {
 		PDWiX::Parameter->throw("Did not get a cpan URI\n");
 	}
 
@@ -123,17 +111,18 @@ sub _abs_uri {
 # Support Methods
 
 sub _DIST {
-	## no critic (ProhibitExplicitReturnUndef)
 	my $it = shift;
 	if ( not( defined $it and not ref $it ) ) {
 		return undef;
 	}
-	if ( $it !~ q|^([A-Z]){2,}/| ) {
+	unless ( $it =~ q|^([A-Z]){2,}/| ) {
 		return undef;
 	}
 	return $it;
 }
 
+1;
+
 no Moose;
 __PACKAGE__->meta->make_immutable;
 
@@ -147,23 +136,17 @@ __END__
 
 Perl::Dist::WiX::Asset::DistBase - Support routines for distribution assets.
 
-=head1 VERSION
-
-This document describes Perl::Dist::WiX::Asset::DistBase version 1.250_100.
-
 =head1 SYNOPSIS
 
 	# Not to be used independently.
 
 =head1 DESCRIPTION
 
-This module provides private support routines that 
+This module provides support routines that 
 L<Perl::Dist::WiX::Asset::Distribution|Perl::Dist::WiX::Asset::Distribution> 
 and L<Perl::Dist::WiX::Asset::DistFile|Perl::Dist::WiX::Asset::DistFile> 
 both use.
 
-There are no public methods defined by this module.
-
 =head1 SUPPORT
 
 Bugs should be reported via the CPAN bug tracker at
@@ -187,7 +170,7 @@ and L<Perl::Dist::WiX::Asset::DistFile|Perl::Dist::WiX::Asset::DistFile>
 
 =head1 COPYRIGHT
 
-Copyright 2009 - 2010 Curtis Jewell.
+Copyright 2009 Curtis Jewell.
 
 Copyright 2007 - 2009 Adam Kennedy.
 
