@@ -1,15 +1,67 @@
 package Perl::Dist::WiX::Asset::File;
 
+use 5.008001;
+use Moose;
+use MooseX::Types::Moose qw( Str );
+use File::Spec::Functions qw( catfile );
+require File::Remove;
+require File::List::Object;
+
+our $VERSION = '1.100';
+$VERSION = eval $VERSION; ## no critic (ProhibitStringyEval)
+
+with 'Perl::Dist::WiX::Role::Asset';
+
+has install_to => (
+	is       => 'ro',
+	isa      => Str,
+	reader   => '_get_install_to',
+	required => 1,
+);
+
+sub install {
+	my $self = shift;
+
+	my $download_dir = $self->_get_download_dir();
+	my $image_dir    = $self->_get_image_dir();
+	my @files;
+
+
+	# Get the file
+	my $tgz = $self->_mirror( $self->_get_url, $download_dir );
+
+	# Copy the file to the target location
+	my $from = catfile( $download_dir, $self->_get_file );
+	my $to   = catfile( $image_dir,    $self->_get_install_to );
+	unless ( -f $to ) {
+		push @files, $to;
+	}
+
+	$self->_copy( $from => $to );
+
+	# Clear the download file
+	File::Remove::remove( \1, $tgz );
+
+	my $filelist =
+	  File::List::Object->new->load_array(@files)
+	  ->filter( $self->_filters );
+
+	return $filelist;
+} ## end sub install
+
+no Moose;
+__PACKAGE__->meta->make_immutable;
+
+1;
+
+__END__
+
 =pod
 
 =head1 NAME
 
 Perl::Dist::WiX::Asset::File - "Single File" asset for a Win32 Perl
 
-=head1 VERSION
-
-This document describes Perl::Dist::WiX::Asset::File version 1.250_100.
-
 =head1 SYNOPSIS
 
   my $binary = Perl::Dist::Asset::File->new(
@@ -21,7 +73,7 @@ This document describes Perl::Dist::WiX::Asset::File version 1.250_100.
 
 B<Perl::Dist::Asset::File> is a data class that provides encapsulation
 and error checking for a single file to be installed unmodified into a
-L<Perl::Dist::WiX|Perl::Dist::WiX>-based Perl distribution.
+L<Perl::Dist::WiX>-based Perl distribution.
 
 It is normally created on the fly by the <Perl::Dist::WiX> C<install_file>
 method (and other things that call it).
@@ -30,122 +82,52 @@ This asset exists to allow for cases where very small tweaks need to be
 done to distributions by dropping in specific single files.
 
 The specification of the location to retrieve the package is done via
-the standard mechanism implemented in 
-L<Perl::Dist::WiX::Role::Asset|Perl::Dist::WiX::Role::Asset>.
-
-=cut
-
-use 5.010;
-use Moose;
-use MooseX::Types::Moose qw( Str );
-use File::Spec::Functions qw( catfile );
-use File::Remove qw();
-use File::List::Object qw();
-
-our $VERSION = '1.250_100';
-$VERSION =~ s/_//ms;
-
-with 'Perl::Dist::WiX::Role::Asset';
+the standard mechanism implemented in L<Perl::Dist::WiX::Role::Asset>.
 
 =head1 METHODS
 
-This class is a L<Perl::Dist::WiX::Role::Asset|Perl::Dist::WiX::Role::Asset>
-and shares its API.
+This class is a L<Perl::Dist::WiX::Role::Asset> and shares its API.
 
 =head2 new
 
 The C<new> constructor takes a series of parameters, validates then
-and returns a new C<Perl::Dist::WiX::Asset::File> object.
+and returns a new B<Perl::Dist::WiX::Asset::File> object.
 
-It inherits all the parameters described in the 
-L<< Perl::Dist::WiX::Role::Asset->new|Perl::Dist::WiX::Role::Asset/new() >> 
-method documentation, and adds an additional parameter described below.
+It inherits all the params described in the L<Perl::Dist::WiX::Role::Asset> C<new>
+method documentation, and adds some additional params.
 
-=head3 install_to
+=over 4
 
-The C<install_to> parameter is the location that the file needs installed
-to, relative to the distribution's image directory.
+=item install_to
 
-=cut
+The required C<install_to> param describes the location that the package
+will be installed to.
 
+The C<install_to> param should be a simple string that represents the
+entire destination path (including file name).
 
+=back
 
-has install_to => (
-	is       => 'ro',
-	isa      => Str,
-	reader   => '_get_install_to',
-	required => 1,
-);
-
-
-
-=head2 install
-
-The install method installs the file described by the
-B<Perl::Dist::WiX::Asset::File> object and returns true or throws
-an exception.
-
-=cut
-
-
-
-sub install {
-	my $self = shift;
-
-	# Set up required variables.
-	my $download_dir = $self->_get_download_dir();
-	my $image_dir    = $self->_get_image_dir();
-	my @files;
-
-	# Get the file.
-	my $file = $self->_mirror( $self->_get_url(), $download_dir );
-
-	# Copy the file to the target location
-	my $from = catfile( $download_dir, $self->_get_file() );
-	my $to   = catfile( $image_dir,    $self->_get_install_to() );
-	if ( not -f $to ) {
-		push @files, $to;
-	}
-
-	$self->_copy( $from => $to );
-
-	# Clear the download file
-	File::Remove::remove( \1, $file );
-
-	my $filelist =
-	  File::List::Object->new()->load_array(@files)
-	  ->filter( $self->_filters() );
-
-	return $filelist;
-} ## end sub install
-
-no Moose;
-__PACKAGE__->meta->make_immutable;
-
-1;
-
-__END__
+The C<new> constructor returns a B<Perl::Dist::Asset::WiX::File> object,
+or throws an exception (dies) if an invalid param is provided.
 
 =head1 SUPPORT
 
 Bugs should be reported via the CPAN bug tracker at
 
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Perl-Dist-WiX>
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Perl-Dist>
 
 For other issues, contact the author.
 
 =head1 AUTHOR
 
-Curtis Jewell E<lt>csjewell@cpan.orgE<gt>
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
-L<Perl::Dist::WiX|Perl::Dist::WiX>, 
-L<Perl::Dist::WiX::Role::Asset|Perl::Dist::WiX::Role::Asset>
+L<Perl::Dist::WiX>, L<Perl::Dist::Asset>
 
-=head1 COPYRIGHT AND LICENSE
-
-Copyright 2009 - 2010 Curtis Jewell.
+=head1 COPYRIGHT
 
 Copyright 2007 - 2009 Adam Kennedy.
 
