@@ -1,51 +1,6 @@
 package Perl::Dist::WiX::Asset::PAR;
 
-=pod
-
-=head1 NAME
-
-Perl::Dist::WiX::Asset::PAR - "Binary .par package" asset for a Win32 Perl
-
-=head1 VERSION
-
-This document describes Perl::Dist::WiX::Asset::PAR version 1.250_100.
-
-=head1 SYNOPSIS
-
-  my $binary = Perl::Dist::Asset::PAR->new(
-    parent => $dist, # A Perl::Dist::WiX object.
-    name   => 'dmake',
-    url    => 'http://parrepository.de/Perl-Dist-PrepackagedPAR-libexpat-2.0.1-MSWin32-x86-multi-thread-anyversion.par',
-  );
-  
-  # Or usually more like this:
-  $perl_dist_wix_obj->install_par(
-    name => 'Perl-Dist-PrepackagedPAR-libexpat',
-    url  => 'http://parrepository.de/Perl-Dist-PrepackagedPAR-libexpat-2.0.1-MSWin32-x86-multi-thread-anyversion.par',
-  );
-
-=head1 DESCRIPTION
-
-B<Perl::Dist::WiX::Asset::PAR> is a data class that provides encapsulation
-and error checking for a "binary .par package" to be installed in a
-L<Perl::Dist::WiX|Perl::Dist::WiX>-based Perl distribution.
-
-It is normally created by the L<install_par|Perl::Dist::WiX::Mixin::Installation/install_par> 
-method of C<Perl::Dist::WiX> (and other things that call it). 
-
-The specification of the location to retrieve the package is done via
-the standard mechanism implemented in L<Perl::Dist::WiX::Asset|Perl::Dist::WiX::Asset>.
-
-The C<install_to> argument of the 
-L<Perl::Dist::WiX::Asset::Library|Perl::Dist::WiX::Asset::Library> 
-asset is not supported by the PAR asset.
-
-See L</PAR FILE FORMAT EXTENSIONS> below for details on how non-Perl binaries
-are installed.
-
-=cut
-
-use 5.010;
+use 5.008001;
 use Moose;
 use MooseX::Types::Moose qw( Str );
 use File::Spec::Functions qw( catdir catfile );
@@ -54,38 +9,11 @@ require SelectSaver;
 require PAR::Dist;
 require IO::String;
 
-our $VERSION = '1.250_100';
-$VERSION =~ s/_//ms;
+our $VERSION = '1.100';
+$VERSION = eval $VERSION; ## no critic (ProhibitStringyEval)
 
 with 'Perl::Dist::WiX::Role::Asset';
 
-=head1 METHODS
-
-This class is a L<Perl::Dist::WiX::Role::Asset|Perl::Dist::WiX::Role::Asset> 
-and shares its API.
-
-=pod
-
-=head2 new
-
-The C<new> constructor takes a series of parameters, validates them
-and returns a new B<Perl::Dist::WiX::Asset::PAR> object.
-
-The C<new> constructor will throw an exception (dies) if an invalid 
-parameter is provided.
-
-It inherits all the parameters described in the 
-L<Perl::Dist::WiX::Asset/new|Perl::Dist::WiX::Asset-E<gt>new()> 
-method documentation, and adds two additional parameters.
-
-=head3 name
-
-The required C<name> parameter is the name of the package for the purposes 
-of identification in output. A sensible default would be the name of
-the primary Perl module in the package.
-
-=cut
-
 has name => (
 	is       => 'ro',
 	isa      => Str,
@@ -93,27 +21,6 @@ has name => (
 	required => 1,
 );
 
-=head3 name
-
-The required C<dist_info> parameter is the location of the source package 
-for the .par file, either as a URL (which should be accessible for 3 years) 
-or as a location on CPAN in the 'AUTHORID/dist-version.tar.gz' format.
-
-=cut
-
-has dist_info => (
-	is       => 'ro',
-	isa      => 'Str',
-	reader   => '_get_dist_info',
-	required => 1,
-);
-
-=head2 install
-
-The C<install> method retrieves the specified .par file and installs it.
-
-=cut
-
 sub install {
 	my $self = shift;
 
@@ -121,10 +28,6 @@ sub install {
 	my $image_dir    = $self->_get_image_dir();
 	my $download_dir = $self->_get_download_dir();
 	my $url          = $self->_get_url();
-	my $vendor =
-	    !$self->_get_parent()->portable()                    ? 1
-	  : ( $self->_get_parent()->perl_major_version() >= 12 ) ? 1
-	  :                                                        0;
 
 	$self->_trace_line( 1, "Preparing $name\n" );
 
@@ -132,7 +35,7 @@ sub install {
 	my $io = IO::String->new($output);
 	my $packlist;
 
-	# When $saved goes out of scope, STDOUT will be restored.
+	# When $saved goes out of context, STDOUT will be restored.
 	{
 		my $saved = SelectSaver->new($io);
 
@@ -145,12 +48,8 @@ sub install {
 		my $perldir = catdir( $image_dir, 'perl' );
 		my $libdir  = catdir( $perldir,   'vendor', 'lib' );
 		my $bindir  = catdir( $perldir,   'bin' );
-		my $cdir    = catdir( $image_dir, 'c' );
-
-		if ( not $vendor ) {
-			$libdir = catdir( $perldir, 'site', 'lib' );
-		}
 		$packlist = catfile( $libdir, 'auto', @module_dirs, '.packlist' );
+		my $cdir = catdir( $image_dir, 'c' );
 
 		# Suppress warnings for resources that don't exist
 		local $WARNING = 0;
@@ -180,7 +79,29 @@ sub install {
 	$self->_trace_line( 2, $output );
 
 	# Get distribution name to add to what's installed.
-	$self->_add_to_distributions_installed( $self->_get_dist_info() );
+	if ( ( defined $url ) and ( $url =~ m{.*/([^/]*)\z}msx ) ) {
+		my $dist_info = $1;
+		$dist_info =~ s{[.] par}{}msx; # Take off .par extension.
+#<<<
+		if ($dist_info =~
+            m{\A(.*?)   # Grab anything that could be the name non-greedily, ...
+			-           # break at a dash,
+			([0-9._]*)  # then try to grab a version,
+			(?:-.*)?    # then discard anything else.
+			\z}msx
+		  )
+#>>>
+		{
+			my ( $dist_name, $dist_ver ) = ( $1, $2 );
+			$dist_info = "${dist_name}-${dist_ver}";
+			$self->_add_to_distributions_installed($dist_info);
+		} else {
+			$self->_trace_line( 1, <<"EOF");
+Could not parse name of .par to determine name and version.
+Source: $dist_info
+EOF
+		}
+	} ## end if ( ( defined $url ) ...)
 
 	# Read in the .packlist and return it.
 	my $filelist =
@@ -197,12 +118,75 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=head1 NAME
+
+Perl::Dist::WiX::Asset::PAR - "Binary .par package" asset for a Win32 Perl
+
+=head1 SYNOPSIS
+
+  my $binary = Perl::Dist::Asset::PAR->new(
+      name       => 'dmake',
+  );
+  
+  # Or usually more like this:
+  $perl_dist_wix_obj->install_par(
+    name => 'Perl-Dist-PrepackagedPAR-libexpat',
+    url  => 'http://parrepository.de/Perl-Dist-PrepackagedPAR-libexpat-2.0.1-MSWin32-x86-multi-thread-anyversion.par',
+  );
+
+=head1 DESCRIPTION
+
+B<Perl::Dist::WiX::Asset::PAR> is a data class that provides encapsulation
+and error checking for a "binary .par package" to be installed in a
+L<Perl::Dist::WiX|Perl::Dist::WiX>-based Perl distribution.
+
+It is normally created by the L<install_par|Perl::Dist::WiX::Installation/install_par> 
+method of C<Perl::Dist::WiX> (and other things that call it). 
+
+The specification of the location to retrieve the package is done via
+the standard mechanism implemented in L<Perl::Dist::WiX::Asset|Perl::Dist::WiX::Asset>.
+
+The C<install_to> argument of the 
+L<Perl::Dist::WiX::Asset::Library|Perl::Dist::WiX::Asset::Library> 
+asset is not supported by the PAR asset.
+
+See L<PAR FILE FORMAT EXTENSIONS> below for details on how non-Perl binaries
+are installed.
+
+=head1 METHODS
+
+This class is a L<Perl::Dist::WiX::Role::Asset|Perl::Dist::WiX::Role::Asset> 
+and shares its API.
+
+=head2 new
+
+The C<new> constructor takes a series of parameters, validates them
+and returns a new B<Perl::Dist::Asset::PAR> object.
+
+It inherits all the parameters described in the C<Perl::Dist::WiX::Asset> 
+C<new> method documentation, and adds an additional parameter.
+
+=over 4
+
+=item name
+
+The required C<name> param is the logical name of the package for the 
+purposes of identification. A sensible default would be the name of
+the primary Perl module in the package.
+
+=back
+
+The C<new> constructor returns a B<Perl::Dist::WiX::Asset::PAR> object,
+or throws an exception (dies) if an invalid param is provided.
+
 =head1 PAR FILE FORMAT EXTENSIONS
 
 This concerns packagers of .par binaries only.
  
 A .par usually mostly contains the blib/ directory after making a Perl module.
-For use with Perl::Dist::Asset::PAR, there are currently four more subdirectories
+For use with Perl::Dist::Asset::PAR, there are currently three more subdirectories
 which will be installed:
 
  blib/c/lib     => goes into the c/lib library directory for non-Perl extensions
@@ -224,12 +208,11 @@ Curtis Jewell E<lt>csjewell@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
-L<Perl::Dist::WiX|Perl::Dist::WiX>, 
-L<Perl::Dist::WiX::Role::Asset|Perl::Dist::WiX::Role::Asset>
+L<Perl::Dist>, L<Perl::Dist::Inno>, L<Perl::Dist::Asset>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 - 2010 Curtis Jewell.
+Copyright 2009 Curtis Jewell.
 
 Copyright 2008 Steffen Mueller, borrowing heavily from
 Adam Kennedy's code.
