@@ -8,7 +8,7 @@ Perl::Dist::WiX::BuildPerl - 4th generation Win32 Perl distribution builder
 
 =head1 VERSION
 
-This document describes Perl::Dist::WiX::BuildPerl version 1.200_101.
+This document describes Perl::Dist::WiX::BuildPerl version 1.090.
 
 =head1 DESCRIPTION
 
@@ -18,73 +18,86 @@ build Perl itself.
 =head1 SYNOPSIS
 
 	# This module is not to be used independently.
-	# It provides methods to be called on a Perl::Dist::WiX object.
 
 =head1 INTERFACE
 
 =cut
 
 use 5.008001;
-use Moose;
-use English qw( -no_match_vars );
-use List::MoreUtils qw( any );
+use strict;
+use warnings;
+use Archive::Zip qw( :ERROR_CODES            );
+use English qw( -no_match_vars          );
+use List::MoreUtils qw( any none                );
 use Params::Util qw( _HASH _STRING _INSTANCE );
-use Readonly qw( Readonly );
+use Readonly qw( Readonly                );
 use Storable qw( retrieve );
 use File::Spec::Functions qw(
   catdir catfile catpath tmpdir splitpath rel2abs curdir
 );
-use Module::CoreList 2.32 qw();
-use Perl::Dist::WiX::Asset::Perl qw();
-use Perl::Dist::WiX::Toolchain qw();
-use File::List::Object qw();
+use Archive::Tar 1.42 qw();
+use Module::CoreList 2.18 qw();
+require File::Remove;
+require File::pushd;
+require File::ShareDir;
+require File::Copy::Recursive;
+require File::PathList;
+require HTTP::Status;
+require IO::String;
+require IO::Handle;
+require LWP::UserAgent;
+require LWP::Online;
+require PAR::Dist;
+require Probe::Perl;
+require SelectSaver;
+require Template;
+require Win32;
+require Perl::Dist::WiX::Asset::Perl;
+require Perl::Dist::WiX::Toolchain;
+require File::List::Object;
 
-our $VERSION = '1.200_101';
-$VERSION =~ s/_//sm;
+our $VERSION = '1.100';
+$VERSION = eval $VERSION; ## no critic (ProhibitStringyEval)
 
-# Keys are what's in the filename, with - being converted to ::.
-# Values are the actual module to use to check whether it's in core.
 Readonly my %CORE_MODULE_FIX => (
-	'IO::Compress'         => 'IO::Compress::Base',
-	'Filter'               => 'Filter::Util::Call',
-	'podlators'            => 'Pod::Man',
-	'Text'                 => 'Text::Tabs',
+	'IO::Compress'        => 'IO::Compress::Base',
+	'Filter'              => 'Filter::Util::Call',
+	'autodie'             => 'Fatal',
+	'Pod'                 => 'Pod::Man',
+	'Text'                => 'Text::Tabs',
+	'PathTools'           => 'Cwd',
+	'Scalar::List::Utils' => 'List::Util',
+);
+
+Readonly my %DIST_TO_MODULE_FIX => (
+	'CGI.pm'               => 'CGI',
+	'Fatal'                => 'autodie',
+	'Locale::Maketext'     => 'Locale-Maketext',
+	'Pod::Man'             => 'Pod',
+	'Text::Tabs'           => 'Text',
 	'PathTools'            => 'Cwd',
-	'Scalar::List::Utils'  => 'List::Util',
-	'Locale::Constants'    => 'Locale::Codes',
 	'TermReadKey'          => 'Term::ReadKey',
 	'Term::ReadLine::Perl' => 'Term::ReadLine',
 	'libwww::perl'         => 'LWP',
-	'LWP::UserAgent'       => 'LWP',
+	'Scalar::List::Utils'  => 'List::Util',
+	'libnet'               => 'Net',
+	'encoding'             => 'Encode',
+	'IO::Scalar'           => 'IO::Stringy',
 );
 
-# Keys are the module name after processing against %CORE_MODULE_FIX.
-# Values are the directory name the .packlist file is in, with
-# / being converted to ::.
-Readonly my %CORE_PACKLIST_FIX => (
-	'IO::Compress::Base' => 'IO::Compress',
-	'Pod::Man'           => 'Pod',
-);
 
-# List of modules to delay building until last when upgrading all CPAN
-# modules (they depend on upgraded versions of modules that originally
-# were upgraded after them.)
 Readonly my @MODULE_DELAY => qw(
   CPANPLUS::Dist::Build
   File::Fetch
   Thread::Queue
 );
 
-
-
 sub _delay_upgrade {
 	my ( $self, $module ) = @_;
 
 	return ( any { $module->id eq $_ } @MODULE_DELAY ) ? 1 : 0;
 }
 
-
-
 sub _module_fix {
 	my ( $self, $module ) = @_;
 
@@ -95,14 +108,6 @@ sub _module_fix {
 
 
 
-sub _packlist_fix {
-	my ( $self, $module ) = @_;
-
-	return ( exists $CORE_PACKLIST_FIX{$module} )
-	  ? $CORE_PACKLIST_FIX{$module}
-	  : $module;
-}
-
 #####################################################################
 # CPAN installation and upgrade support
 
@@ -124,9 +129,7 @@ the default tasklist after the "perl toolchain" is installed.
 
 sub install_cpan_upgrades { ## no critic(ProhibitExcessComplexity)
 	my $self = shift;
-
-	# Check for Perl - we can't do things out of order.
-	if ( not $self->bin_perl() ) {
+	unless ( $self->bin_perl ) {
 		PDWiX->throw(
 			'Cannot install CPAN modules yet, perl is not installed');
 	}
@@ -134,90 +137,51 @@ sub install_cpan_upgrades { ## no critic(ProhibitExcessComplexity)
 	# Get list of modules to be upgraded.
 	# (The list is saved as a Storable arrayref of CPAN::Module objects.)
 	my $cpan_info_file = $self->_get_cpan_upgrades_list();
-	my $module_info    = retrieve($cpan_info_file);
+	my $module_info    = retrieve $cpan_info_file;
 
-	# Now go through the loop for each module.
 	my $force;
 	my @delayed_modules;
 	require CPAN;
   MODULE:
 
 	for my $module ( @{$module_info} ) {
-		$force = $self->force();
+		$force = $self->force;
 
-		# Skip modules that we want to skip.
 		next MODULE if $self->_skip_upgrade($module);
 
 		# Net::Ping seems to require that a web server be
 		# available on localhost in order to pass tests.
-		if ( $module->cpan_file() =~ m{/Net-Ping-\d}msx ) {
+		if ( $module->cpan_file =~ m{/Net-Ping-\d}msx ) {
 			$self->_install_cpan_module( $module, 1 );
 			next MODULE;
 		}
 
 		# Safe seems to have problems inside a build VM, but
 		# not outside.  Forcing to be safe.
-		if ( $module->cpan_file() =~ m{/Safe-\d}msx ) {
+		if ( $module->cpan_file =~ m{/Safe-\d}msx ) {
 			$self->_install_cpan_module( $module, 1 );
 			next MODULE;
 		}
 
 		# Locale::Maketext::Simple 0.20 has a test bug. Forcing.
-		if (
-			$module->cpan_file() =~ m{/Locale-Maketext-Simple-0 [.] 20}msx )
+		if ( $module->cpan_file =~ m{/Locale-Maketext-Simple-0 [.] 20}msx )
 		{
 			$self->_install_cpan_module( $module, 1 );
 			next MODULE;
 		}
 
-		# Time-HiRes is timing-dependent, of course.
-		if ( $module->cpan_file() =~ m{/Time-HiRes-}msx ) {
-			$self->_install_cpan_module( $module, 1 );
-			next MODULE;
-		}
-
-		# Module::Install needs a few more modules.
-		if (    ( $module->cpan_file() =~ m{/Module-Install-\d}msx )
-			and ( $module->cpan_version() > 0.79 ) )
+		if (    ( $module->cpan_file =~ m{/Module-Install-\d}msx )
+			and ( $module->cpan_version > 0.79 ) )
 		{
+
+			# We need a few more modules.
 			$self->install_modules(qw( File::Remove YAML::Tiny ));
 			$self->_install_cpan_module( $module, $force );
 			next MODULE;
 		}
 
-		# There's a problem with extracting these two files, so
-		# upgrading to these versions, instead...
-		if ( $module->cpan_file() =~
-			/Unicode-Collate-0 [.] 53-withoutworldwriteables/msx )
-		{
-			$self->install_distribution(
-				name     => 'SADAHIRO/Unicode-Collate-0.53.tar.gz',
-				mod_name => 'Unicode::Collate',
-				$self->_install_location(1),
-				$force
-				? ( force => 1 )
-				: (),
-			);
-			next MODULE;
-		} ## end if ( $module->cpan_file...)
-
-		if ( $module->cpan_file() =~
-			/Unicode-Normalize-1 [.] 06-withoutworldwriteables/msx )
-		{
-			$self->install_distribution(
-				name     => 'SADAHIRO/Unicode-Normalize-1.06.tar.gz',
-				mod_name => 'Unicode::Normalize',
-				$self->_install_location(1),
-				$force
-				? ( force => 1 )
-				: (),
-			);
-			next MODULE;
-		} ## end if ( $module->cpan_file...)
-
-		# Get rid of the old ExtUtils::MakeMaker files.
-		if (    ( $module->cpan_file() =~ m{/ExtUtils-MakeMaker-\d}msx )
-			and ( $module->cpan_version() > 6.50 ) )
+		if (    ( $module->cpan_file =~ m{/ExtUtils-MakeMaker-\d}msx )
+			and ( $module->cpan_version > 6.50 ) )
 		{
 			$self->remove_file(qw{perl lib ExtUtils MakeMaker bytes.pm});
 			$self->remove_file(qw{perl lib ExtUtils MakeMaker vmsish.pm});
@@ -225,27 +189,26 @@ sub install_cpan_upgrades { ## no critic(ProhibitExcessComplexity)
 			next MODULE;
 		}
 
-		# The podlators dist needs a few more modules to install on 5.8.9.
-		if (    ( $module->cpan_file() =~ m{/podlators-\d}msx )
-			and ( $module->cpan_version() > 2.00 )
-			and ( $self->perl_version() < 5100 ) )
+		if (    ( $module->cpan_file =~ m{/podlators-\d}msx )
+			and ( $module->cpan_version > 2.00 )
+			and ( $self->perl_version < 5100 ) )
 		{
 			$self->install_modules(qw( Pod::Escapes Pod::Simple ));
 			$self->_install_cpan_module( $module, $force );
 			next MODULE;
 		}
 
-		# New CGI.pm versions require FCGI.
-		if (    ( $module->cpan_file() =~ m{/CGI [.] pm-\d}msx )
-			and ( $module->cpan_version() > 3.45 ) )
+		if (    ( $module->cpan_file =~ m{/CGI [.] pm-\d}msx )
+			and ( $module->cpan_version > 3.45 ) )
 		{
 			$self->install_modules(qw( FCGI ));
 			$self->_install_cpan_module( $module, $force );
 			next MODULE;
 		}
 
-		# If we're on the "delay this module" list, do so.
 		if ( $self->_delay_upgrade($module) ) {
+
+			# Delay these module until last.
 			unshift @delayed_modules, $module;
 			next MODULE;
 		}
@@ -253,7 +216,6 @@ sub install_cpan_upgrades { ## no critic(ProhibitExcessComplexity)
 		$self->_install_cpan_module( $module, $force );
 	} ## end for my $module ( @{$module_info...})
 
-	# NOW install delayed modules!
 	for my $module (@delayed_modules) {
 		$self->_install_cpan_module( $module, $force );
 	}
@@ -262,7 +224,8 @@ sub install_cpan_upgrades { ## no critic(ProhibitExcessComplexity)
 	# Yes, I know that technically it's a core module with
 	# non-core dependencies, and that's ugly. I've just got
 	# to live with it.
-	my $autodie_location = $self->file(qw(perl lib autodie.pm));
+	my $autodie_location =
+	  catfile( $self->image_dir, qw(perl lib autodie.pm) );
 
 	if ( -e $autodie_location ) {
 		$self->install_modules(qw( Win32::Process IPC::System::Simple ));
@@ -270,21 +233,31 @@ sub install_cpan_upgrades { ## no critic(ProhibitExcessComplexity)
 
 	# Getting CPANPLUS config file installed if required.
 	my $cpanp_config_location =
-	  $self->file(qw(perl lib CPANPLUS Config.pm));
+	  catfile( $self->image_dir, qw(perl lib CPANPLUS Config.pm) );
+
 	if ( -e $cpanp_config_location ) {
 
+		# Installing 0.89_02 because of accumulated fixes,
+		# including one in which the config set
+		# by us works better.
+		$self->install_distribution(
+			name             => 'BINGOS/CPANPLUS-0.89_02.tar.gz',
+			mod_name         => 'CPANPLUS',
+			makefilepl_param => ['INSTALLDIRS=perl'],
+			buildpl_param    => [ '--installdirs', 'core' ],
+		);
+
 		$self->trace_line( 1,
 			"Getting CPANPLUS config file ready for patching\n" );
 
 		$self->patch_file(
-			'perl/lib/CPANPLUS/Config.pm' => $self->image_dir(),
+			'perl/lib/CPANPLUS/Config.pm' => $self->image_dir,
 			{ dist => $self, } );
-	}
+	} ## end if ( -e $cpanp_config_location)
 
-	# Install dev version of CPAN if we haven't already.
-	if ( not $self->fragment_exists('CPAN') ) {
+	if ( not exists $self->{fragments}->{CPAN} ) {
 		$self->install_distribution(
-			name             => 'ANDK/CPAN-1.94_58.tar.gz',
+			name             => 'ANDK/CPAN-1.94_52.tar.gz',
 			mod_name         => 'CPAN',
 			makefilepl_param => ['INSTALLDIRS=perl'],
 			buildpl_param    => [ '--installdirs', 'core' ],
@@ -297,10 +270,11 @@ sub install_cpan_upgrades { ## no critic(ProhibitExcessComplexity)
 sub _get_cpan_upgrades_list {
 	my $self = shift;
 
-	# Get the CPAN url.
+	# Generate the CPAN installation script
 	my $url = $self->cpan()->as_string();
 
-	# Generate the CPAN installation script
+	$url =~ s{file:///C:/}{file://C:/}msx;
+
 	my $cpan_string = <<"END_PERL";
 print "Loading CPAN...\\n";
 use CPAN;
@@ -372,7 +346,8 @@ unless (%need) {
 }
 	
 END_PERL
-	my $cpan_info_file = catfile( $self->output_dir(), 'cpan.info' );
+
+	my $cpan_info_file = catfile( $self->output_dir, 'cpan.info' );
 	$cpan_string .= <<"END_PERL";
 nstore \\\@toget, '$cpan_info_file';
 print "Completed collecting information on all modules\\n";
@@ -380,9 +355,9 @@ print "Completed collecting information on all modules\\n";
 exit 0;
 END_PERL
 
-	# Dump the CPAN script to a temp file and execute.
+	# Dump the CPAN script to a temp file and execute
 	$self->trace_line( 1, "Running upgrade of all modules\n" );
-	my $cpan_file = catfile( $self->build_dir(), 'cpan_string.pl' );
+	my $cpan_file = catfile( $self->build_dir, 'cpan_string.pl' );
   SCOPE: {
 		my $CPAN_FILE;
 		open $CPAN_FILE, '>', $cpan_file
@@ -392,7 +367,7 @@ END_PERL
 		close $CPAN_FILE
 		  or PDWiX->throw("CPAN script close failed: $OS_ERROR");
 	}
-	$self->execute_perl($cpan_file)
+	$self->_run3( $self->bin_perl, $cpan_file )
 	  or PDWiX->throw('CPAN script execution failed');
 	PDWiX->throw('Failure detected during cpan upgrade, stopping')
 	  if $CHILD_ERROR;
@@ -400,61 +375,29 @@ END_PERL
 	return $cpan_info_file;
 } ## end sub _get_cpan_upgrades_list
 
-sub _install_location {
-	my ( $self, $core ) = @_;
-
-	# Return the correct location information.
-	my $vendor =
-	    !$self->portable()                    ? 1
-	  : ( $self->perl_major_version() >= 12 ) ? 1
-	  :                                         0;
-
-	if ($core) {
-		return (
-			makefilepl_param => ['INSTALLDIRS=perl'],
-			buildpl_param    => [ '--installdirs', 'core' ],
-		);
-	} elsif ($vendor) {
-		return (
-			makefilepl_param => ['INSTALLDIRS=vendor'],
-			buildpl_param    => [ '--installdirs', 'vendor' ],
-		);
-	} else {
-		return (
-			makefilepl_param => ['INSTALLDIRS=site'],
-			buildpl_param    => [ '--installdirs', 'site' ],
-		);
-	}
-} ## end sub _install_location
-
-
-
 sub _install_cpan_module {
 	my ( $self, $module, $force ) = @_;
-
-	# Collect information.
-	$force = $force or $self->force();
-	my $perl_version = $self->perl_version_literal();
-	my $module_id    = $self->_module_fix( $module->id() );
-	my $module_file  = substr $module->cpan_file(), 5;
+	$force = $force or $self->force;
+	my $perl_version = $self->perl_version_literal;
+	my $module_id    = $self->_module_fix( $module->id );
+	my $module_file  = substr $module->cpan_file, 5;
 #<<<
 	my $core =
 	  exists $Module::CoreList::version{ $perl_version }{ $module_id }
 	  ? 1
 	  : 0;
-
-	# Override core determination for this module.
-	# (It's not in core, but other modules that this distribution
-	# installs are)
-	if ('Locale::Codes' eq $module_id) {
-		$core = 1;
-	}
-
-	# Actually do the installation.
 	$self->install_distribution(
 		name     => $module_file,
-		mod_name => $self->_packlist_fix($module_id),
-		$self->_install_location($core),
+		mod_name => $module_id,
+		$core
+		  ? (
+		      makefilepl_param => ['INSTALLDIRS=perl'],
+			  buildpl_param => ['--installdirs', 'core'],
+		    )
+		  : (
+		      makefilepl_param => ['INSTALLDIRS=vendor'],
+			  buildpl_param => ['--installdirs', 'vendor'],
+		    ),
 		$force
 		  ? ( force => 1 )
 		  : (),
@@ -463,42 +406,34 @@ sub _install_cpan_module {
 	return 1;
 } ## end sub _install_cpan_module
 
-
-
 sub _skip_upgrade {
 	my ( $self, $module ) = @_;
 
-	# DON'T try to install Perl at this point!
-	return 1 if $module->cpan_file() =~ m{/perl-5 [.]}msx;
+	# DON'T try to install Perl.
+	return 1 if $module->cpan_file =~ m{/perl-5 [.]}msx;
 
 	# DON'T try to install Term::ReadKey, we
 	# already upgraded it.
-	return 1 if $module->id() eq 'Term::ReadKey';
+	return 1 if $module->id eq 'Term::ReadKey';
 
 	# DON'T try to install Win32API::Registry, we
 	# already upgraded it as far as we can.
-	return 1 if $module->id() eq 'Win32API::Registry';
+	return 1 if $module->id eq 'Win32API::Registry';
 
 	# If the ID is CGI::Carp, there's a bug in the index.
-	return 1 if $module->id() eq 'CGI::Carp';
+	return 1 if $module->id eq 'CGI::Carp';
 
 	# If the ID is ExtUtils::MakeMaker, we've already installed it.
 	# There were some files gotten rid of after 6.50, so
 	# install_cpan_upgrades thinks that it needs to upgrade
-	# those files using it when using perl versions that
-	# still had those files.
+	# those files using it.
 
 	# This code is in here for safety as of yet.
-	return 1 if $module->cpan_file() =~ m{/ExtUtils-MakeMaker-6 [.] 50}msx;
-
-	# Skip B::C, it does not install on 5.8.9.
-	return 1 if $module->cpan_file() =~ m{/B-C-1 [.]}msx;
+	return 1 if $module->cpan_file =~ m{/ExtUtils-MakeMaker-6 [.] 50}msx;
 
 	return 0;
 } ## end sub _skip_upgrade
 
-
-
 #####################################################################
 # Perl installation support
 
@@ -508,7 +443,7 @@ The C<install_perl> method is a minimal routine provided to call the
 correct L<install_perl_*|/install_perl_*> routine for the version of perl 
 being created.
 
-Returns true or throws an exception.
+Returns true (technically, the object that called it), or throws an exception.
 
 This is recommended to be used as a task in the tasklist, and is in 
 the default tasklist after the "c toolchain" is installed.
@@ -517,76 +452,22 @@ the default tasklist after the "c toolchain" is installed.
 
 # Just hand off to the larger set of Perl install methods.
 sub install_perl {
-	my $self = shift;
-
-	# Check for the method, then call it.
-	my $install_perl_method = 'install_perl_' . $self->perl_version();
-	if ( not $self->can($install_perl_method) ) {
+	my $self                = shift;
+	my $install_perl_method = 'install_perl_' . $self->perl_version;
+	unless ( $self->can($install_perl_method) ) {
 		PDWiX->throw(
 			"Cannot generate perl, missing $install_perl_method method in "
 			  . ref $self );
 	}
 	$self->$install_perl_method(@_);
 
-	# Add the perllocal.pod to the perl fragment.
 	$self->add_to_fragment( 'perl',
-		[ $self->file(qw(perl lib perllocal.pod)) ] );
+		[ catfile( $self->image_dir, qw(perl lib perllocal.pod) ) ] );
 
 	return 1;
 } ## end sub install_perl
 
-
-
-sub _create_perl_toolchain {
-	my $self = shift;
-	my $cpan = $self->cpan();
-
-	# Quick check for a nonexistent minicpan directory.
-	if ( _INSTANCE( $cpan, 'URI::file' ) ) {
-		if ( not -d $cpan->dir() ) {
-			PDWiX::Directory->throw(
-				message =>
-				  'Directory referred to by CPAN url does not exist',
-				dir => $cpan->dir() );
-		}
-	}
-
-	# Prefetch and predelegate the toolchain so that it
-	# fails early if there's a problem
-	$self->trace_line( 1, "Pregenerating toolchain...\n" );
-	my $force = {};
-	if ( $self->perl_version =~ m/\A512/ms ) {
-		$force = { 'Pod::Text' => 'RRA/podlators-2.3.1.tar.gz' };
-	}
-	my $toolchain = Perl::Dist::WiX::Toolchain->new(
-		perl_version => $self->perl_version_literal(),
-		cpan         => $cpan->as_string(),
-		bits         => $self->bits(),
-		force        => $force,
-	) or PDWiX->throw('Failed to resolve toolchain modules');
-	if ( not eval { $toolchain->delegate(); 1; } ) {
-		PDWiX::Caught->throw(
-			message => 'Delegation error occured',
-			info    => defined($EVAL_ERROR) ? $EVAL_ERROR : 'Unknown error',
-		);
-	}
-	if ( defined $toolchain->get_error() ) {
-		PDWiX::Caught->throw(
-			message => 'Failed to generate toolchain distributions',
-			info    => $toolchain->get_error() );
-	}
-
-	$self->_set_toolchain($toolchain);
-
-	# Make the perl directory if it hasn't been made already.
-	$self->make_path( $self->dir('perl') );
-
-	return $toolchain;
-} ## end sub _create_perl_toolchain
-
-
-
-=head2 install_perl_* (* = git, 589, 5100, 5101, 5120, or 5121)
+=head2 install_perl_* (* = 589, 5100, or 5101)
 
 	$self->install_perl_5100;
 
@@ -622,7 +503,7 @@ A short summary of the process would be that it downloads or otherwise
 fetches the named package, unpacks it, copies out any license files from
 the source code, then tweaks the Win32 makefile to point to the specific
 build directory, and then runs make/make test/make install. It also
-registers some environment variables for addition to the installer
+registers some environment variables for addition to the Inno Setup
 script.
 
 It is normally called directly by C<install_perl_*> rather than
@@ -635,22 +516,44 @@ error.
 
 =cut
 
-
-
 #####################################################################
 # Perl 5.8.9 Support
 
 sub install_perl_589 {
 	my $self = shift;
 
-	# Get the information required for Perl's toolchain.
-	my $toolchain = $self->_create_perl_toolchain();
+	# Prefetch and predelegate the toolchain so that it
+	# fails early if there's a problem
+	$self->trace_line( 1, "Pregenerating toolchain...\n" );
+	my $toolchain = Perl::Dist::WiX::Toolchain->new(
+		perl_version => $self->perl_version_literal,
+		cpan         => $self->cpan->as_string
+	) or PDWiX->throw('Failed to resolve toolchain modules');
+	unless ( eval { $toolchain->delegate; 1; } ) {
+		PDWiX::Caught->throw(
+			message => 'Delegation error occured',
+			info    => defined($EVAL_ERROR) ? $EVAL_ERROR : 'Unknown error',
+		);
+	}
+	if ( defined $toolchain->get_error() ) {
+		PDWiX::Caught->throw(
+			message => 'Failed to generate toolchain distributions',
+			info    => $toolchain->get_error() );
+	}
 
-	# Install the main perl distribution.
+	$self->{toolchain} = $toolchain;
+
+	# Make the perl directory if it hasn't been made alreafy.
+	$self->make_path( catdir( $self->image_dir, 'perl' ) );
+
+	# Install the main perl distributions
 	$self->install_perl_bin(
-		url       => 'http://strawberryperl.com/package/perl-5.8.9.tar.gz',
-		toolchain => $toolchain,
-		patch     => [ qw{
+		name       => 'perl',
+		url        => 'http://strawberryperl.com/package/perl-5.8.9.tar.gz',
+		unpack_to  => 'perl',
+		install_to => 'perl',
+		toolchain  => $toolchain,
+		patch      => [ qw{
 			  lib/CPAN/Config.pm
 			  win32/config.gc
 			  win32/config_sh.PL
@@ -667,52 +570,68 @@ sub install_perl_589 {
 	return 1;
 } ## end sub install_perl_589
 
-
-
 sub install_perl_bin {
 	my $self = shift;
+	my $perl = Perl::Dist::WiX::Asset::Perl->new(
+		parent => $self,
+		force  => $self->forceperl() || $self->force(),
+		@_,
+	);
 
-	# Check for an error in the object.
-	if ( not $self->bin_make() ) {
+	unless ( $self->bin_make ) {
 		PDWiX->throw('Cannot build Perl yet, no bin_make defined');
 	}
 
-	# Install perl.
-	my $perl = Perl::Dist::WiX::Asset::Perl->new(
-		parent => $self,
-		@_,
-	);
 	$perl->install();
 
 	# Should have a perl to use now.
-	$self->_set_bin_perl( $self->file(qw/perl bin perl.exe/) );
-
-	# Create the site/bin path so we can add it to the PATH.
-	$self->make_path( catdir( $self->image_dir(), qw(perl site bin) ) );
+	$self->{bin_perl} = catfile( $self->image_dir, qw/perl bin perl.exe/ );
 
 	# Add to the environment variables
-	$self->add_path( 'perl', 'site', 'bin' );
-	$self->add_path( 'perl', 'bin' );
+	$self->add_env_path( 'perl', 'bin' );
 
 	return 1;
 } ## end sub install_perl_bin
 
 
-
 #####################################################################
-# Perl 5.10.x Support
+# Perl 5.10.0 Support
 
 sub install_perl_5100 {
 	my $self = shift;
 
-	# Get the information required for Perl's toolchain.
-	my $toolchain = $self->_create_perl_toolchain();
+	# Prefetch and predelegate the toolchain so that it
+	# fails early if there's a problem
+	$self->trace_line( 1, "Pregenerating toolchain...\n" );
+	my $toolchain = Perl::Dist::WiX::Toolchain->new(
+		perl_version => $self->perl_version_literal,
+		cpan         => $self->cpan->as_string
+	) or PDWiX->throw('Failed to resolve toolchain modules');
+	unless ( eval { $toolchain->delegate; 1; } ) {
+		PDWiX::Caught->throw(
+			message => 'Delegation error occured',
+			info    => defined($EVAL_ERROR) ? $EVAL_ERROR : 'Unknown error',
+		);
+	}
+	if ( defined $toolchain->get_error() ) {
+		PDWiX::Caught->throw(
+			message => 'Failed to generate toolchain distributions',
+			info    => $toolchain->get_error() );
+	}
+
+	$self->{toolchain} = $toolchain;
+
+	# Make the perl directory if it hasn't been made already.
+	$self->make_path( catdir( $self->image_dir, 'perl' ) );
 
 	# Install the main binary
 	$self->install_perl_bin(
+		name      => 'perl',
 		url       => 'http://strawberryperl.com/package/perl-5.10.0.tar.gz',
-		toolchain => $toolchain,
-		patch     => [ qw{
+		unpack_to => 'perl',
+		install_to => 'perl',
+		toolchain  => $toolchain,
+		patch      => [ qw{
 			  lib/ExtUtils/Command.pm
 			  lib/CPAN/Config.pm
 			  win32/config.gc
@@ -731,18 +650,41 @@ sub install_perl_5100 {
 } ## end sub install_perl_5100
 
 
-
 sub install_perl_5101 {
 	my $self = shift;
 
-	# Get the information required for Perl's toolchain.
-	my $toolchain = $self->_create_perl_toolchain();
+	# Prefetch and predelegate the toolchain so that it
+	# fails early if there's a problem
+	$self->trace_line( 1, "Pregenerating toolchain...\n" );
+	my $toolchain = Perl::Dist::WiX::Toolchain->new(
+		perl_version => $self->perl_version_literal,
+		cpan         => $self->cpan->as_string
+	) or PDWiX->throw('Failed to resolve toolchain modules');
+	unless ( eval { $toolchain->delegate; 1; } ) {
+		PDWiX::Caught->throw(
+			message => 'Delegation error occured',
+			info    => defined($EVAL_ERROR) ? $EVAL_ERROR : 'Unknown error',
+		);
+	}
+	if ( defined $toolchain->get_error() ) {
+		PDWiX::Caught->throw(
+			message => 'Failed to generate toolchain distributions',
+			info    => $toolchain->get_error() );
+	}
+
+	$self->{toolchain} = $toolchain;
+
+	# Make the perl directory if it hasn't been made already.
+	$self->make_path( catdir( $self->image_dir, 'perl' ) );
 
 	# Install the main binary
 	$self->install_perl_bin(
+		name      => 'perl',
 		url       => 'http://strawberryperl.com/package/perl-5.10.1.tar.gz',
-		toolchain => $toolchain,
-		patch     => [ qw{
+		unpack_to => 'perl',
+		install_to => 'perl',
+		toolchain  => $toolchain,
+		patch      => [ qw{
 			  lib/CPAN/Config.pm
 			  win32/config.gc
 			  win32/config_sh.PL
@@ -760,115 +702,10 @@ sub install_perl_5101 {
 } ## end sub install_perl_5101
 
 
-
-#####################################################################
-# Perl 5.12.0 Support
-
-sub install_perl_5120 {
-	my $self = shift;
-
-	# Get the information required for Perl's toolchain.
-	my $toolchain = $self->_create_perl_toolchain();
-
-	# Install the main binary
-	$self->install_perl_bin(
-		url => 'http://strawberryperl.com/package/perl-5.12.0.tar.bz2',
-		toolchain => $toolchain,
-		patch     => [ qw{
-			  lib/CPAN/Config.pm
-			  win32/config.gc
-			  win32/config.gc64nox
-			  win32/config_sh.PL
-			  win32/config_H.gc
-			  win32/config_H.gc64nox
-			  }
-		],
-		license => {
-			'perl-5.12.0/Readme'   => 'perl/Readme',
-			'perl-5.12.0/Artistic' => 'perl/Artistic',
-			'perl-5.12.0/Copying'  => 'perl/Copying',
-		},
-	);
-
-	return 1;
-} ## end sub install_perl_5120
-
-
-
-#####################################################################
-# Perl 5.12.1 Support
-
-sub install_perl_5121 {
-	my $self = shift;
-
-	# Get the information required for Perl's toolchain.
-	my $toolchain = $self->_create_perl_toolchain();
-
-	# Install the main binary
-	$self->install_perl_bin(
-		url => 'http://strawberryperl.com/package/perl-5.12.1.tar.bz2',
-		toolchain => $toolchain,
-		patch     => [ qw{
-			  lib/CPAN/Config.pm
-			  win32/config.gc
-			  win32/config.gc64nox
-			  win32/config_sh.PL
-			  win32/config_H.gc
-			  win32/config_H.gc64nox
-			  }
-		],
-		license => {
-			'perl-5.12.1/Readme'   => 'perl/Readme',
-			'perl-5.12.1/Artistic' => 'perl/Artistic',
-			'perl-5.12.1/Copying'  => 'perl/Copying',
-		},
-	);
-
-	return 1;
-} ## end sub install_perl_5121
-
-
-
-#####################################################################
-# Git checkout support
-
-sub install_perl_git {
-	my $self = shift;
-
-	# Get the information required for Perl's toolchain.
-	my $toolchain = $self->_create_perl_toolchain();
-
-	# Get where the git checkout is.
-	my $checkout = $self->git_checkout();
-
-	# Install the main binary
-	$self->install_perl_bin(
-		url       => URI::file->new($checkout)->as_string(),
-		file      => $checkout,
-		toolchain => $toolchain,
-		patch     => [ qw{
-			  lib/CPAN/Config.pm
-			  win32/config.gc
-			  win32/config_sh.PL
-			  win32/config_H.gc
-			  }
-		],
-		license => {
-			'perl-git/Readme'   => 'perl/Readme',
-			'perl-git/Artistic' => 'perl/Artistic',
-			'perl-git/Copying'  => 'perl/Copying',
-		},
-		git => $self->git_describe(),
-	);
-
-	return 1;
-} ## end sub install_perl_git
-
-
-
 #####################################################################
 # Perl Toolchain Support
 
+
 =head2 install_perl_toolchain
 
 The C<install_perl_toolchain> method is a routine provided to install the
@@ -883,21 +720,21 @@ the default tasklist after the perl interpreter is installed.
 =cut
 
 sub install_perl_toolchain {
-	my $self = shift;
+	my $self      = shift;
+	my $toolchain = $self->toolchain;
 
-	# Retrieves and verifies the toolchain.
-	my $toolchain = $self->_get_toolchain();
 	if ( 0 == $toolchain->dist_count() ) {
 		PDWiX->throw('Toolchain did not get collected');
 	}
 
-	# Install the toolchain dists
 	my ( $core, $module_id );
+
+	# Install the toolchain dists
 	foreach my $dist ( $toolchain->get_dists() ) {
 		my $automated_testing = 0;
 		my $release_testing   = 0;
 		my $overwritable      = 0;
-		my $force             = $self->force();
+		my $force             = $self->force;
 		if ( $dist =~ /Scalar-List-Util/msx ) {
 
 			# Does something weird with tainting
@@ -931,9 +768,24 @@ sub install_perl_toolchain {
 			# 1.9402 fails its tests... ANDK says it's a test bug.
 			# Alias agrees that we include 1.94_51 because of the fix
 			# for the Win32 file:// bug.
-			$dist  = 'ANDK/CPAN-1.94_58.tar.gz';
+			$dist  = 'ANDK/CPAN-1.94_52.tar.gz';
 			$force = 1;
 		}
+		if ( $dist =~ /ExtUtils-ParseXS-2[.]20(?:02)?[.]tar[.]gz/msx ) {
+
+			# 2.20 and 2.2002 are buggy on 5.8.9.
+			$dist = 'DAGOLDEN/ExtUtils-ParseXS-2.20_05.tar.gz';
+		}
+		if ( $dist =~ /Win32API-Registry-0 [.] 31/msx ) {
+
+			# 0.31 does not include a Makefile.PL.
+			$dist = 'BLM/Win32API-Registry-0.30.tar.gz';
+		}
+		if ( $dist =~ /Module-Build-/msx ) {
+
+			# 0.31 does not include a Makefile.PL.
+			$dist = 'DAGOLDEN/Module-Build-0.3500_01.tar.gz';
+		}
 		if ( $dist =~ /ExtUtils-MakeMaker-/msx ) {
 
 			# There are modules that overwrite portions of this one.
@@ -941,19 +793,15 @@ sub install_perl_toolchain {
 		}
 		if ( $dist =~ /Win32API-Registry-/msx ) {
 
-			# This module needs forced on Vista
-			# (and probably 2008/Win7 as well).
+	   # This module needs forced on Vista (and probably 2008/Win7 as well).
 			$force = 1;
 		}
 		if ( $dist =~ /Win32-TieRegistry-/msx ) {
 
-			# This module needs forced on Vista
-			# (and probably 2008/Win7 as well).
+	   # This module needs forced on Vista (and probably 2008/Win7 as well).
 			$force = 1;
 		}
 
-		# Actually DO the installation, now
-		# that we've got the information we need.
 		$module_id = $self->_module_fix( $self->_name_to_module($dist) );
 		$core =
 		  exists $Module::CoreList::version{ $self->perl_version_literal() }
@@ -961,12 +809,20 @@ sub install_perl_toolchain {
 #<<<
 		$self->install_distribution(
 			name              => $dist,
-			mod_name          => $self->_packlist_fix($module_id),
+			mod_name          => $module_id,
 			force             => $force,
 			automated_testing => $automated_testing,
 			release_testing   => $release_testing,
 			overwritable      => $overwritable,
-			$self->_install_location($core),
+			$core
+			  ? (
+				  makefilepl_param => ['INSTALLDIRS=perl'],
+				  buildpl_param => ['--installdirs', 'core'],
+				)
+			  : (
+				  makefilepl_param => ['INSTALLDIRS=vendor'],
+				  buildpl_param => ['--installdirs', 'vendor'],
+			    ),
 		);
 #>>>
 	} ## end foreach my $dist ( $toolchain...)
@@ -974,15 +830,12 @@ sub install_perl_toolchain {
 	return $self;
 } ## end sub install_perl_toolchain
 
-
-
 sub _name_to_module {
 	my $self = shift;
 	my $dist = shift;
 
-	# Convert a distribution name with dashes to
-	# a module name with double colons.
 	$self->trace_line( 3, "Trying to get module name out of $dist\n" );
+
 #<<<
 	my ( $module ) = $dist =~ m{\A  # Start the string...
 					[A-Za-z/]*      # With a string of letters and slashes
@@ -996,6 +849,8 @@ sub _name_to_module {
 	return $module;
 } ## end sub _name_to_module
 
+
+
 1;
 
 __END__
@@ -1026,12 +881,12 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
-L<Perl::Dist::WiX|Perl::Dist::WiX>, 
+L<Perl::Dist|Perl::Dist>, L<Perl::Dist::WiX|Perl::Dist::WiX>, 
 L<http://ali.as/>, L<http://csjewell.comyr.com/perl/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 - 2010 Curtis Jewell.
+Copyright 2009 Curtis Jewell.
 
 Copyright 2008 - 2009 Adam Kennedy.
 
