@@ -8,49 +8,124 @@ Perl::Dist::WiX::Checkpoint - Checkpoint support for Perl::Dist::WiX
 
 =head1 VERSION
 
-This document describes Perl::Dist::WiX::Checkpoint version 1.200_101.
-
-=head1 SYNOPSIS
-
-	# This module is not to be used independently.
-	# It provides methods to be called on a Perl::Dist::WiX object.
-
-	$dist = Perl::Dist::WiX->new(
-		# ...
-		checkpoint_before => 5,
-		checkpoint_after => [8, 9],
-		checkpoint_stop => 9,
-		# ...
-	);
+This document describes Perl::Dist::WiX::Checkpoint version 1.100.
 
 =head1 DESCRIPTION
 
 This module provides the routines that Perl::Dist::WiX uses in order to
 support checkpointing.
 
+=head1 SYNOPSIS
+
+	# This module is not to be used independently.
+	$dist = Perl::Dist::WiX->new(
+		# ...
+		checkpoint_before => 5
+		checkpoint_after => [8, 9],
+		checkpoint_stop => 9,
+		# ...
+	);
+
 =head1 INTERFACE
 
 There are 2 portions to the interface to this module - the parameters to 
-L<new()|Perl::Dist::WiX/new> (documented in that module), and the 
-object methods that Perl::Dist::WiX uses to coordinate checkpointing, as
-described below.
+L<new()|Perl::Dist::WiX/new> (listed under C<Parameters> below), and the 
+object calls that Perl::Dist::WiX uses to coordinate checkpointing.
 
-These routines are not meant to be called from external classes.  
-L<Perl::Dist::WiX|Perl::Dist::WiX> calls these routines as required.
+=head2 Parameters
+
+=head3 tasklist
+
+	$dist = Perl::Dist::WiX->new(
+		# ...
+		tasklist => [
+			# Install the core C toolchain
+			'install_c_toolchain',
+
+			# Install any additional C libraries
+			'install_c_libraries',
+
+			# Install the Perl binary
+			'install_perl',
+
+			# Install the Perl toolchain
+			'install_perl_toolchain',
+
+			# Install additional Perl modules
+			'install_cpan_upgrades',
+
+			# Install the Win32 extras
+			'install_win32_extras',
+
+			# Apply optional portability support
+			'install_portable',
+
+			# Remove waste and temporary files
+			'remove_waste',
+
+			# Regenerate file fragments
+			'regenerate_fragments',
+			
+			# Install any extra custom non-Perl software on top of Perl.
+			# This is primarily added for the benefit of Parrot.
+			'install_custom',
+
+			# Write out the distributions
+			'write',
+		];
+		# ...
+	);
+
+This is the parameter that specifies what tasks to execute.  The names 
+are of object methods of Perl::Dist::WiX (or its subclasses) that will be 
+executed in order, and their task numbers (as used below) will begin with 
+1 and increment in sequence.
+
+The default task list for Perl::Dist::WiX is as shown above.  Subclasses should
+insert their tasks in this list, rather than overriding routines shown above.
+
+=head3 checkpoint_after
+
+C<checkpoint_after> is given an arrayref of task numbers.  After each task in 
+the list, Perl::Dist::WiX will stop and save a checkpoint.
+
+[ 0 ] is the default, meaning that you do not wish to save a checkpoint anywhere.
+
+=head3 checkpoint_stop
+
+C<checkpoint_stop> stops execution after the specified task if no error has 
+happened before then.
+
+0 is the default, meaning that you do not wish to stop unless an error occurs.
+
+=head3 checkpoint_before
+
+C<checkpoint_before> is given an integer to know when to load a checkpoint.
+Unlike the other parameters, this is based on the task number that is GOING 
+to execute, rather than the task number that just executed, so that if a 
+checkpoint was saved after (for example) task 5, this parameter should be 6
+in order to load the checkpoint and start on task 6.
+
+0 is the default, meaning that you do not wish to stop unless an error occurs.
 
 =cut
 
 use 5.008001;
-use Moose;
+use strict;
+use warnings;
 use English qw( -no_match_vars );
-use List::Util qw( first );
+use List::Util qw( first          );
 use File::Spec::Functions qw( catdir catfile );
 use File::Remove qw();
-use Storable qw();
-use Clone qw(clone);
 
-our $VERSION = '1.200_101';
-$VERSION =~ s/_//ms;
+our $VERSION = '1.100';
+$VERSION = eval $VERSION; ## no critic (ProhibitStringyEval)
+
+#####################################################################
+# Checkpoint Support
+
+# NOTE: "The object that called it" is supposed to be a Perl::Dist::WiX
+# object.
 
 =head2 checkpoint_task
 
@@ -62,10 +137,6 @@ The second parameter is the task number that goes with that subroutine.
 
 Returns true (technically, the object that called it), or throws an exception.
 
-This routine is called for each task (a task is a method on 
-C<Perl::Dist::WiX> or a subclass of it) defined in the 
-L<tasklist|Perl::Dist::WiX/tasklist> parameter to C<Perl::Dist::WiX->new()>.
-
 =cut
 
 sub checkpoint_task {
@@ -74,38 +145,29 @@ sub checkpoint_task {
 	my $step = shift;
 
 	# Are we loading at this step?
-	if ( $self->checkpoint_before() == $step ) {
-		$self->checkpoint_load();
+	if ( $self->checkpoint_before == $step ) {
+		$self->checkpoint_load;
 	}
 
 	# Skip if we are loading later on
-	if ( $self->checkpoint_before() > $step ) {
+	if ( $self->checkpoint_before > $step ) {
 		$self->trace_line( 0, "Skipping $task (step $step.)\n" );
 	} else {
 		my $t = time;
-
-		if ( not $self->can($task) ) {
-			PDWiX::NotTask->throw(
-				class => ref $self,
-				task  => $task,
-				step  => $step
-			);
-		}
-
 		$self->$task();
 		$self->trace_line( 0,
 			    "Completed $task (step $step) in "
 			  . ( time - $t )
 			  . " seconds\n" );
-	} ## end else [ if ( $self->checkpoint_before...)]
+	}
 
 	# Are we saving at this step?
-	if ( defined first { $step == $_ } @{ $self->checkpoint_after() } ) {
-		$self->checkpoint_save();
+	if ( defined first { $step == $_ } @{ $self->checkpoint_after } ) {
+		$self->checkpoint_save;
 	}
 
 	# Are we stopping at this step?
-	if ( $self->checkpoint_stop() == $step ) {
+	if ( $self->checkpoint_stop == $step ) {
 		return 0;
 	}
 
@@ -114,14 +176,12 @@ sub checkpoint_task {
 
 =head2 checkpoint_file
 
-Returns the file that the Perl::Dist::WiX object is stored in when
-C<checkpoint_save> is called.
+Returns the file that the Perl::Dist::WiX object is stored in.
 
 =cut
 
 sub checkpoint_file {
-	my $self = shift;
-	return catfile( $self->checkpoint_dir(), 'self.dat' );
+	return catfile( $_[0]->checkpoint_dir, 'self.dat' );
 }
 
 =head2 checkpoint_self
@@ -137,141 +197,110 @@ sub checkpoint_self {
 =head2 checkpoint_save
 
 Saves a checkpoint within the checkpoint subdirectory of 
-L<< Perl::Dist::WiX-E<gt>temp_dir()|Perl::Dist::WiX/temp_dir >>
+L<Perl::Dist::WiX-E<gt>temp_dir|Perl::Dist::WiX/temp_dir>
 
 =cut
 
 sub checkpoint_save {
 	my $self = shift;
-	unless ( $self->temp_dir() ) {
+	unless ( $self->temp_dir ) {
 		PDWiX->throw('Checkpoints require a temp_dir to be set');
 	}
 
 	# Clear out any existing checkpoint.
 	$self->trace_line( 1, "Removing old checkpoint\n" );
-	$self->remake_path( $self->checkpoint_dir() );
+	$self->{checkpoint_dir} = catfile( $self->temp_dir, 'checkpoint' );
+	$self->remake_path( $self->checkpoint_dir );
 
 	# Copy the paths into the checkpoint directory.
 	$self->trace_line( 1, "Copying checkpoint directories...\n" );
 	foreach my $dir (qw{ build_dir download_dir image_dir output_dir }) {
 		my $from = $self->$dir();
-		my $to = catdir( $self->checkpoint_dir(), $dir );
-		$self->copy_file( $from => $to );
+		my $to = catdir( $self->checkpoint_dir, $dir );
+		$self->_copy( $from => $to );
 	}
 
+	# Store the main object.
 	# Blank the checkpoint values to prevent load/save loops, and remove
 	# things we can recreate later.
-	my $copy = clone($self);
-	$copy->_clear_patch_template();
-	$copy->_clear_guidgen();
-	$copy->_clear_user_agent();
-	$copy->_clear_trace_object();
-	$copy->_set_checkpoint_before(0);
-	$copy->_set_checkpoint_after( [0] );
-	$copy->_set_checkpoint_stop(0);
+	my $copy = {
+		%{$self},
+		checkpoint_before => 0,
+		checkpoint_after  => [0],
+		checkpoint_stop   => 0,
+		tt_exists         => ( defined $self->{template_toolkit} ? 1 : 0 ),
+		template_toolkit  => undef,
+		user_agent        => undef,
+		'_guidgen'        => undef,
+		misc              => undef,
+	};
 
-	# Store the main object.
 	local $Storable::Deparse = 1;
-	eval { Storable::nstore( $copy, $self->checkpoint_file() ); 1; }
-	  or PDWiX::Caught::Storable->throw(
-		message => $EVAL_ERROR,
-		object  => $copy
-	  );
+	Storable::nstore( $copy, $self->checkpoint_file );
 
 	return 1;
 } ## end sub checkpoint_save
 
-=head2 checkpoint_load
+=head2 checkpoint_save
 
 Restores a checkpoint saved to the checkpoint subdirectory of 
-L<< Perl::Dist::WiX-E<gt>temp_dir()|Perl::Dist::WiX/temp_dir >> with 
+L<Perl::Dist::WiX-E<gt>temp_dir|Perl::Dist::WiX/temp_dir> with 
 L</checkpoint_save>.
 
 =cut
 
 sub checkpoint_load {
-	## no critic(ProtectPrivateSubs)
-	my $self  = shift;
-	my $class = ref $self;
+	my $self = shift;
+	unless ( $self->temp_dir ) {
+		PDWiX->throw('Checkpoints require a temp_dir to be set');
+	}
 
 	# Does the checkpoint exist?
-	unless ( -d $self->checkpoint_dir() ) {
-		PDWiX::Directory->throw(
-			message => 'Checkpoint directory does not exist',
-			dir     => $self->checkpoint_dir() );
+	$self->trace_line( 1, "Removing old checkpoint\n" );
+	$self->{checkpoint_dir} =
+	  File::Spec->catfile( $self->temp_dir, 'checkpoint', );
+	unless ( -d $self->checkpoint_dir ) {
+		PDWiX->throw('Failed to find checkpoint directory');
 	}
-	unless ( -f $self->checkpoint_file() ) {
-		PDWiX::File->throw(
-			message => 'Checkpoint file does not exist',
-			file    => $self->checkpoint_file() );
-	}
-
-	$self->trace_line( 1, "Preparing to restore checkpoint\n" );
 
 	# If we want a future checkpoint, save it.
-	my $checkpoint_after = $self->checkpoint_after() || 0;
-	my $checkpoint_stop  = $self->checkpoint_stop()  || 0;
-
-	# Save off the user agent for later restoration.
-	my $user_agent = $self->user_agent();
-
-	# Clear the directory tree.
-	$self->_clear_directory_tree();
-	Perl::Dist::WiX::DirectoryTree2->_clear_instance();
+	my $checkpoint_after = $self->{checkpoint_after} || 0;
+	my $checkpoint_stop  = $self->{checkpoint_stop}  || 0;
 
 	# Load the stored hash over our object
 	local $Storable::Eval = 1;
-	my $stored = Storable::retrieve( $self->checkpoint_file() );
+	my $stored = Storable::retrieve( $self->checkpoint_file );
 	%{$self} = %{$stored};
 
 	# Restore any possible future checkpoint.
-	$self->_set_checkpoint_after($checkpoint_after);
-	$self->_set_checkpoint_stop($checkpoint_stop);
+	$self->{checkpoint_after} = $checkpoint_after;
+	$self->{checkpoint_stop}  = $checkpoint_stop;
 
-	# Grab the directory tree stuff before we clear it.
-	my $directory_tree_root = $self->{_directories}->{_root};
-	my $app_name            = $self->{_directories}->{app_name};
-	my $app_dir             = $self->{_directories}->{app_dir};
+	# Reload the template object if it existed before.
+	if ( $self->{tt_exists} ) {
+		$self->patch_template();
+		delete $self->{tt_exists};
+	}
 
-	# Clear the directory tree instance again, then
-	# recreate it with the saved stuff.
-	$self->_clear_directory_tree();
-	Perl::Dist::WiX::DirectoryTree2->_clear_instance();
-	$self->_set_directories(
-		Perl::Dist::WiX::DirectoryTree2->new(
-			app_dir  => $app_dir,
-			app_name => $app_name,
-			_root    => $directory_tree_root,
-		) );
+	## no critic(ProtectPrivateSubs)
 
 	# Reload the misc object.
-	$self->_clear_trace_object();
 	WiX3::Trace::Object->_clear_instance();
 	WiX3::Traceable->_clear_instance();
-	$self->_set_trace_object(
-		WiX3::Traceable->new( tracelevel => $self->trace() ) );
+	$self->{misc} = WiX3::Traceable->new( tracelevel => $self->{trace} );
 
-	# Reload GUID generator.
-	$self->_clear_guidgen();
 	WiX3::XML::GeneratesGUID::Object->_clear_instance();
-	$self->_set_guidgen(
-		WiX3::XML::GeneratesGUID::Object->new(
-			_sitename => $self->sitename() ) );
-
-	# Reload LWP user agent.
-	$self->_clear_user_agent();
-	$self->_set_user_agent($user_agent);
-
-	# Clear other objects for reloading.
-	$self->_clear_patch_template();
+	$self->{_guidgen} =
+	  WiX3::XML::GeneratesGUID::Object->new(
+		_sitename => $self->{sitename} );
 
 	# Pull all the directories out of the storage.
 	$self->trace_line( 0, "Restoring checkpoint directories...\n" );
 	foreach my $dir (qw{ build_dir download_dir image_dir output_dir }) {
-		my $from = File::Spec->catdir( $self->checkpoint_dir(), $dir );
+		my $from = File::Spec->catdir( $self->checkpoint_dir, $dir );
 		my $to = $self->$dir();
 		File::Remove::remove($to);
-		$self->copy_file( $from => $to );
+		$self->_copy( $from => $to );
 	}
 
 	return 1;
@@ -325,7 +354,7 @@ L<http://ali.as/>, L<http://csjewell.comyr.com/perl/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 - 2010 Curtis Jewell.
+Copyright 2009 Curtis Jewell.
 
 Copyright 2008 - 2009 Adam Kennedy.
 
