@@ -8,7 +8,7 @@ Perl::Dist::WiX::Installation - Basic installation routines
 
 =head1 VERSION
 
-This document describes Perl::Dist::WiX::Installation version 1.200_100.
+This document describes Perl::Dist::WiX::Installation version 1.100.
 
 =head1 DESCRIPTION
 
@@ -18,7 +18,6 @@ install files.
 =head1 SYNOPSIS
 
 	# This module is not to be used independently.
-	# It provides methods to be called on a Perl::Dist::WiX object.
 
 =head1 INTERFACE
 
@@ -37,10 +36,12 @@ require Perl::Dist::WiX::Asset::Launcher;
 require Perl::Dist::WiX::Asset::Library;
 require Perl::Dist::WiX::Asset::Module;
 require Perl::Dist::WiX::Asset::PAR;
+
+# require Perl::Dist::WiX::Asset::Perl;
 require Perl::Dist::WiX::Asset::Website;
 
-our $VERSION = '1.200_100';
-$VERSION =~ s/_//ms;
+our $VERSION = '1.100';
+$VERSION = eval $VERSION; ## no critic (ProhibitStringyEval)
 
 =pod
 
@@ -58,8 +59,6 @@ Returns true or throws an exception on error.
 
 =cut
 
-
-
 sub install_binary {
 	my $self   = shift;
 	my $binary = Perl::Dist::WiX::Asset::Binary->new(
@@ -73,8 +72,6 @@ sub install_binary {
 	return $filelist;
 } ## end sub install_binary
 
-
-
 =head2 install_library
 
   $self->install_library(
@@ -89,8 +86,6 @@ Returns true or throws an exception on error.
 
 =cut
 
-
-
 sub install_library {
 	my $self    = shift;
 	my $library = Perl::Dist::WiX::Asset::Library->new(
@@ -104,7 +99,6 @@ sub install_library {
 }
 
 
-
 =pod
 
 =head2 install_distribution
@@ -152,8 +146,6 @@ Returns true or throws an exception on error.
 
 =cut
 
-
-
 sub install_distribution {
 	my $self = shift;
 	my $dist = Perl::Dist::WiX::Asset::Distribution->new(
@@ -166,8 +158,6 @@ sub install_distribution {
 	return $self;
 }
 
-
-
 =pod
 
 =head2 install_distribution_from_file
@@ -211,8 +201,6 @@ Returns true or throws an exception on error.
 
 =cut
 
-
-
 sub install_distribution_from_file {
 	my $self = shift;
 
@@ -222,7 +210,7 @@ sub install_distribution_from_file {
 	);
 
 	my $filelist = $dist->install();
-	my $mod_id   = $dist->get_name();
+	my $mod_id   = $dist->get_module_name();
 
 	$mod_id =~ s{::}{_}msg;
 	$mod_id =~ s{-}{_}msg;
@@ -233,7 +221,8 @@ sub install_distribution_from_file {
 	return $self;
 } ## end sub install_distribution_from_file
 
-
+## search_packlists should not be needed.
+## If it's needed, pull it out of version 1.000.
 
 =pod
 
@@ -262,15 +251,10 @@ the module.
 The optional 'packlist' param sshould be 0 if a .packlist file is not 
 installed with the module.
 
-This does NOT install the dependencies of the module named - they have
-to be installed before the named module, in one way or another.
-
 Returns true or throws an exception on error.
 
 =cut
 
-
-
 sub install_module {
 	my $self   = shift;
 	my $module = Perl::Dist::WiX::Asset::Module->new(
@@ -291,8 +275,6 @@ sub install_module {
 	return $self;
 } ## end sub install_module
 
-
-
 =pod
 
 =head2 install_modules
@@ -311,8 +293,6 @@ underlying C<install_module> call other than the name.
 
 =cut
 
-
-
 sub install_modules {
 	my $self = shift;
 
@@ -323,8 +303,6 @@ sub install_modules {
 	return $self;
 }
 
-
-
 =pod
 
 =head2 install_par
@@ -341,8 +319,6 @@ Returns true on success or throws an exception on error.
 
 =cut
 
-
-
 sub install_par {
 	my $self = shift;
 
@@ -366,8 +342,6 @@ sub install_par {
 	return $self;
 } ## end sub install_par
 
-
-
 =pod
 
 =head2 install_file
@@ -422,8 +396,6 @@ or throws an exception on error.
 
 =cut
 
-
-
 sub install_file {
 	my $self = shift;
 	my $file = Perl::Dist::WiX::Asset::File->new(
@@ -436,8 +408,6 @@ sub install_file {
 	return $filelist;
 }
 
-
-
 =pod
 
 =head2 install_launcher
@@ -451,7 +421,7 @@ The C<install_launcher> method is used to describe a binary program
 launcher that will be added to the Windows "Start" menu when the
 distribution is installed.
 
-It takes two compulsory parameters.
+It takes two compulsory param.
 
 The compulsory 'name' param is the name of the launcher, and the text
 that label will be displayed in the start menu (Currently this only
@@ -465,8 +435,6 @@ Returns true or throws an exception on error.
 
 =cut
 
-
-
 sub install_launcher {
 	my $self     = shift;
 	my $launcher = Perl::Dist::WiX::Asset::Launcher->new(
@@ -479,8 +447,6 @@ sub install_launcher {
 	return $self;
 }
 
-
-
 =pod
 
 =head2 install_website
@@ -511,8 +477,6 @@ Returns true on success, or throws an exception on error.
 
 =cut
 
-
-
 sub install_website {
 	my $self    = shift;
 	my $website = Perl::Dist::WiX::Asset::Website->new(
@@ -553,12 +517,12 @@ Curtis Jewell E<lt>csjewell@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
-L<Perl::Dist::WiX|Perl::Dist::WiX>, 
+L<Perl::Dist|Perl::Dist>, L<Perl::Dist::WiX|Perl::Dist::WiX>, 
 L<http://ali.as/>, L<http://csjewell.comyr.com/perl/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 - 2010 Curtis Jewell.
+Copyright 2009 Curtis Jewell.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
