@@ -4,11 +4,11 @@ package Perl::Dist::WiX::ReleaseNotes;
 
 =head1 NAME
 
-Perl::Dist::WiX::ReleaseNotes - Creates accessory files.
+Perl::Dist::WiX::ReleaseNotes - 4th generation Win32 Perl distribution builder
 
 =head1 VERSION
 
-This document describes Perl::Dist::WiX::ReleaseNotes version 1.102.
+This document describes Perl::Dist::WiX::ReleaseNotes version 1.100.
 
 =head1 DESCRIPTION
 
@@ -18,55 +18,44 @@ make the distributions.txt and the release notes files.
 =head1 SYNOPSIS
 
 	# This module is not to be used independently.
-	# It provides methods to a Perl::Dist::WiX object.
 
 =head1 INTERFACE
 
 =cut
 
 use 5.008001;
-use Moose;
+use strict;
+use warnings;
 use English qw( -no_match_vars );
-use File::Spec::Functions qw( catfile );
-require IO::File;
-require Template;
-require File::List::Object;
+use File::Spec::Functions qw(
+  catdir catfile catpath tmpdir splitpath rel2abs curdir
+);
+use File::Remove qw();
+use File::pushd qw();
+use File::ShareDir qw();
+use IO::File qw();
+use Template qw();
+use Win32 qw();
 
-our $VERSION = '1.102_101';
-$VERSION =~ s/_//ms;
-
-=head2 release_notes_filename
-
-The C<release_notes_filename> method returns the name of the release 
-notes framework file.
-
-=cut
+our $VERSION = '1.100';
+$VERSION = eval $VERSION; ## no critic (ProhibitStringyEval)
 
 sub release_notes_filename {
 	my $self = shift;
 	my $filename =
-	    $self->perl_version_human() . q{.}
-	  . $self->build_number()
-	  . ( $self->beta_number() ? '.beta' : q{} ) . '.html';
+	    $self->perl_version_human . q{.}
+	  . $self->build_number
+	  . ( $self->beta_number ? '.beta' : q{} ) . '.html';
 
 	return $filename;
 }
 
-
-
-=head2 create_release_notes
-
-The C<create_release_notes> method creates the framework file for the 
-release notes to upload to a web site.
-
-=cut
-
 sub create_release_notes {
 	my $self = shift;
 	my $dist_list;
 	my ( $name, $ver );
 
-	foreach my $dist ( $self->_get_distributions() ) {
+	foreach my $dist ( @{ $self->{distributions_installed} } ) {
 		( $name, $ver ) = $dist =~ m{(.*)-(?:v?)([0-9._]*)}msx;
 		$dist_list .= "<tr><td>$name</td><td>$ver</td></tr>\n";
 	}
@@ -112,7 +101,7 @@ sub create_release_notes {
 	$fh->print($dist_txt);
 	$fh->close;
 
-	$self->add_output_file($dist_file);
+	push @{ $self->{output_file} }, $dist_file;
 
 	return 1;
 } ## end sub create_release_notes
@@ -124,45 +113,29 @@ sub create_release_notes {
 # NOTE: "The object that called it" is supposed to be a Perl::Dist::WiX
 # object.
 
+=head2 create_distribution_list
+
+The C<create_distribution_list> method creates the DISTRIBUTIONS.txt file
+that contains the list of distributions that are installed, and adds it to
+the .msi.
+
+=cut
+
 sub _add_to_distributions_installed {
 	my $self = shift;
 	my $dist = shift;
-	$self->_add_distribution($dist);
+	$self->{distributions_installed} =
+	  [ @{ $self->{distributions_installed} }, $dist ];
 
 	return;
 }
 
-
-
-=head2 create_distribution_list
-
-The C<create_distribution_list> method creates the DISTRIBUTIONS.txt file.
-
-=cut
-
 sub create_distribution_list {
 	my $self = shift;
-
-	return $self->create_distribution_list_file('DISTRIBUTIONS.txt');
-}
-
-
-
-=head2 create_distribution_list_file
-
-The C<create_distribution_list_file> method creates a distribution list file
-(like DISTRIBUTIONS.txt) that contains the list of distributions that are 
-installed, and adds it to the .msi.
-
-=cut
-
-sub create_distribution_list_file {
-	my $self           = shift;
-	my $dist_file_name = shift;
 	my $dist_list;
 	my ( $name, $ver );
 
-	foreach my $dist ( $self->_get_distributions() ) {
+	foreach my $dist ( @{ $self->{distributions_installed} } ) {
 		( $name, $ver ) = $dist =~ m{(.*)-(?:v?)([0-9._]*)}msx;
 		$dist_list .= "    $name $ver\n";
 	}
@@ -174,7 +147,7 @@ sub create_distribution_list_file {
 	};
 
 	my $tt = Template->new(
-		INCLUDE_PATH => [ $self->dist_dir(), $self->wix_dist_dir(), ],
+		INCLUDE_PATH => [ $self->dist_dir, $self->wix_dist_dir, ],
 		ABSOLUTE     => 1,
 	  )
 	  || PDWiX::Caught->throw(
@@ -182,13 +155,13 @@ sub create_distribution_list_file {
 		info    => Template->error(),
 	  );
 
-	$tt->process( "${dist_file_name}.tt", $vars, \$dist_txt )
+	$tt->process( 'DISTRIBUTIONS.txt.tt', $vars, \$dist_txt )
 	  || PDWiX::Caught->throw(
 		message => 'Template error',
 		info    => $tt->error(),
 	  );
 
-	my $dist_file = catfile( $self->image_dir, $dist_file_name );
+	my $dist_file = catfile( $self->image_dir, q{DISTRIBUTIONS.txt} );
 	my $fh = IO::File->new( $dist_file, 'w' );
 
 	$self->trace_line( 2, "Creating distribution list at $dist_file\n" );
@@ -201,12 +174,10 @@ sub create_distribution_list_file {
 	$fh->print($dist_txt);
 	$fh->close;
 
-	# Create a fragment for the distribution list to go into.
-	my $dist_file_list = File::List::Object->new()->add_file($dist_file);
-	$self->insert_fragment( 'perl_dist_list', $dist_file_list );
+	$self->add_to_fragment( 'perl_licenses', [$dist_file] );
 
 	return 1;
-} ## end sub create_distribution_list_file
+} ## end sub create_distribution_list
 
 1;
 
@@ -241,7 +212,7 @@ L<http://ali.as/>, L<http://csjewell.comyr.com/perl/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 - 2010 Curtis Jewell.
+Copyright 2009 Curtis Jewell.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
