@@ -6,34 +6,36 @@ package Perl::Dist::WiX::Util::Machine;
 
 Perl::Dist::WiX::Util::Machine - Generate an entire set of related distributions
 
-=head1 VERSION
+=head1 DESCRIPTION
 
-This document describes Perl::Dist::WiX::Util::Machine version 1.250_100.
+Perl::Dist::WiX::Util::Machine is a Perl::Dist multiplexor.
+
+It provides the functionality required to generate several
+variations of a distribution at the same time.
 
 =head1 SYNOPSIS
 
-	# This is what Perl::Dist::Strawberry will do, as of version 2.03.
+	# This is what Perl::Dist::Strawberry does, as of version 2.00_02.
 
 	# Create the machine
 	my $machine = Perl::Dist::WiX::Util::Machine->new(
-		class  => 'Perl::Dist::Strawberry',
+		class => 'Perl::Dist::Strawberry',
 		common => [ forceperl => 1 ],
-		skip   => [4, 6],
 	);
 
 	# Set the different versions
 	$machine->add_dimension('version');
 	$machine->add_option('version',
-		perl_version => '5101',
+		perl_version => '589',
+	    build_number => 2,
 	);
 	$machine->add_option('version',
 		perl_version => '5101',
+	);
+	$machine->add_option('version',
+		perl_version => '5100',
 		portable     => 1,
 	);
-	$machine->add_option('version',
-		perl_version => '5121',
-		relocatable  => 1,
-	);
 
 	# Set the different paths
 	$machine->add_dimension('drive');
@@ -47,36 +49,8 @@ This document describes Perl::Dist::WiX::Util::Machine version 1.250_100.
 	);
 
 	$machine->run();
-	# Creates 8 distributions (really 6, because you can't have
-	# portable => 1 and zip => 0 for the same distribution,
-	# nor do we need to build a relocatable version twice.)	
-
-=head1 DESCRIPTION
-
-Perl::Dist::WiX::Util::Machine is a Perl::Dist::WiX multiplexer.
-
-It provides the functionality required to generate several
-variations of a distribution at the same time.
-
-=cut
-
-use 5.010;
-use Moose 0.90;
-use Moose::Util::TypeConstraints;
-use MooseX::Types::Moose qw( Str ArrayRef HashRef Bool Int );
-use Params::Util qw( _IDENTIFIER _HASH0 _DRIVER _CLASSISA );
-use English qw( -no_match_vars );
-use File::Copy qw();
-use File::Copy::Recursive qw();
-use File::Spec::Functions qw( catdir );
-use File::Remove qw();
-use File::HomeDir qw();
-use List::MoreUtils qw( none );
-use Perl::Dist::WiX::Exceptions;
-use WiX3::Traceable qw();
-
-our $VERSION = '1.250_100';
-$VERSION =~ s/_//ms;
+	# Creates 6 distributions (really 5, because you can't have
+	# portable => 1 and zip => 0 for the same distribution.)	
 
 =head1 INTERFACE
 
@@ -84,63 +58,24 @@ $VERSION =~ s/_//ms;
 
 	my $machine = Perl::Dist::WiX::Util::Machine->new(
 		class => 'Perl::Dist::WiX',
-		common => { forceperl => 1, },
+		common => [ forceperl => 1, ],
 		output => 'C:\',
-		trace  => 2,
 	);
 
-This method creates a new object that generates multiple distributions,
-using the parameters below.
+This method creates a new machine to generate multiple distributions, 
+using two required parameters and one optional parameter.
 
 =head3 class (required)
 
-This required parameter specifies the class that this object uses to 
-create distributions.
+This parameter specifies the class that the machine uses to create 
+distributions.
 
 It must be a subclass of L<Perl::Dist::WiX|Perl::Dist::WiX>.
 
-=cut
-
-
-
-has class => (
-	is  => 'ro',
-	isa => subtype(
-		'Str' => where {
-			$_ ||= q{};
-			_CLASSISA( $_, 'Perl::Dist::WiX' );
-		},
-		message {
-			'Not a subclass of Perl::Dist::WiX.';
-		},
-	),
-	required => 1,
-	reader   => '_get_class',
-);
-
-
-
-=head3 common
-
-This required parameter specifies the parameters that are common to all 
-the distributions that will be created, as an array or hash reference.
-
-For the parameters that you can put here, see the documentation for the
-class that is specified in the C<'class'> parameter and its subclasses.
-
-=cut
-
-
-
-has common => (
-	traits   => ['Array'],
-	is       => 'bare',
-	isa      => ArrayRef,
-	required => 1,
-	handles  => { '_get_common' => 'elements', },
-);
-
+=head3 common (required)
 
+This parameter specifies the parameters that are common to all the 
+distributions that will be created.
 
 =head3 output (optional)
 
@@ -151,69 +86,30 @@ thinks is the desktop.
 
 =cut
 
+use 5.008001;
+use Moose 0.90;
+use MooseX::Types::Moose qw( Str ArrayRef HashRef Bool );
+use Params::Util qw( _IDENTIFIER _HASH0 _DRIVER );
+use English qw( -no_match_vars );
+use File::Copy qw();
+use File::Copy::Recursive qw();
+use File::Spec::Functions qw( catdir );
+use File::Remove qw();
+use File::HomeDir qw();
+use List::MoreUtils qw( none );
+use Perl::Dist::WiX::Exceptions;
 
+our $VERSION = '1.100';
+$VERSION = eval $VERSION; ## no critic(ProhibitStringyEval)
 
-has output => (
-	is      => 'ro',
-	isa     => Str,
-	default => sub { return File::HomeDir->my_desktop(); },
-	reader  => '_get_output',
+has class => (
+	is       => 'ro',
+	isa      => Str,
+	required => 1,
+	reader   => '_get_class',
 );
 
-
-
-=head3 skip (optional)
-
-This is a reference to a list of distributions to skip building, in numerical order.
-
-Note that the numerical order the distributions is dependent on which order 
-you put the dimensions in - the last dimension is changed first. For 
-example, if there are 3 dimensions, with the first dimension having 3 
-options and the other 2 dimensions having 2 options, the numbering is 
-as follows:
-
-   1: 1, 1, 1   2: 1, 1, 2   3: 1, 2, 1   4: 1, 2, 2
-   5: 2, 1, 1 ...   
-   9: 3, 1, 1 ...
-
-If you wanted to skip the two distributions where the first dimension was 
-going to use its second option and the last dimension was going to use its 
-first option, you would pass [ 5, 7 ] to this option.
-   
-=cut
-
-
-
-has skip => (
-	traits  => ['Array'],
-	is      => 'bare',
-	isa     => ArrayRef,
-	default => sub { return [0]; },
-	handles => { '_get_skip_values' => 'elements', },
-);
-
-
-
-=head3 trace (optional)
-
-This is the trace level for all objects.
-
-If none is specified, it defaults to 1.
-
-=cut
-
-
-
-has trace => (
-	is      => 'ro',
-	isa     => Int,
-	default => 1,
-	reader  => '_get_trace',
-);
-
-
-
-has _dimensions => (
+has dimensions => (
 	traits   => ['Array'],
 	is       => 'bare',
 	isa      => ArrayRef,
@@ -225,7 +121,15 @@ has _dimensions => (
 	},
 );
 
-has _options => (
+has skip => (
+	traits  => ['Array'],
+	is      => 'bare',
+	isa     => ArrayRef,
+	default => sub { return [0]; },
+	handles => { '_get_skip_values' => 'elements', },
+);
+
+has options => (
 	traits   => ['Hash'],
 	is       => 'bare',
 	isa      => HashRef,
@@ -239,7 +143,7 @@ has _options => (
 	},
 );
 
-has _state => (
+has state => (
 	traits   => ['Hash'],
 	is       => 'bare',
 	isa      => HashRef,
@@ -252,9 +156,9 @@ has _state => (
 	},
 );
 
-has _eos => (
+has eos => (
 	traits   => ['Bool'],
-	is       => 'bare',
+	is       => 'ro',
 	isa      => Bool,
 	default  => 0,
 	init_arg => undef,
@@ -262,20 +166,20 @@ has _eos => (
 	handles  => { '_set_eos' => 'set', },
 );
 
-has _traceobject => (
-	is       => 'bare',
-	init_arg => undef,
-	lazy     => 1,
-	reader   => '_get_traceobject',
-	builder  => '_build_traceobject',
+has output => (
+	is      => 'ro',
+	isa     => Str,
+	default => sub { return File::HomeDir->my_desktop; },
+	reader  => '_get_output',
 );
 
-sub _build_traceobject {
-	my $self = shift;
-
-	return WiX3::Traceable->new( tracelevel => $self->_get_trace() );
-}
-
+has common => (
+	traits   => ['Array'],
+	is       => 'bare',
+	isa      => ArrayRef,
+	required => 1,
+	handles  => { '_get_common' => 'elements', },
+);
 
 #####################################################################
 # Constructor
@@ -289,8 +193,9 @@ sub BUILDARGS {
 	} elsif ( 0 == @_ % 2 ) {
 		%args = (@_);
 	} else {
-		PDWiX->throw( 'Parameters incorrect (not a hashref or hash)'
-			  . 'for Perl::Dist::WiX::Util::Machine' );
+		PDWiX->throw(
+'Parameters incorrect (not a hashref or hash) for Perl::Dist::WiX::Util::Machine'
+		);
 	}
 
 	if ( _HASH0( $args{common} ) ) {
@@ -304,14 +209,15 @@ sub BUILD {
 	my $self = shift;
 
 	# Check params
-	if ( not _DRIVER( $self->_get_class(), 'Perl::Dist::WiX' ) ) {
+	unless ( _DRIVER( $self->_get_class(), 'Perl::Dist::WiX' ) ) {
 		PDWiX->throw('Missing or invalid class param');
 	}
 
 	my $output = $self->_get_output();
-	if ( not -d $output or not -w $output ) {
-		PDWiX->throw( "The output directory '$output' does not "
-			  . 'exist, or is not writable' );
+	unless ( -d $output and -w $output ) {
+		PDWiX->throw(
+"The output directory '$output' does not exist, or is not writable"
+		);
 	}
 
 	return $self;
@@ -339,8 +245,6 @@ generated.
 
 =cut
 
-
-
 sub add_dimension {
 	my $self = shift;
 	my $name = _IDENTIFIER(shift)
@@ -357,28 +261,12 @@ sub add_dimension {
 	return 1;
 } ## end sub add_dimension
 
-
-
 =head2 add_option
 
-  $machine->add_option('perl_version',
-    perl_version => '5120',
-    relocatable => 1,
-  );
-
 Adds a 'option' (a set of parameters that can change) to a dimension. 
 
-The first parameter is the dimension to add the option to, and the 
-other parameters are stored in the dimension to be used when creating
-objects.
-
-The combination of the C<'common'> parameters and one option from each
-dimension is used when creating or iterating through distribution objects.
-
 =cut
 
-
-
 sub add_option {
 	my $self = shift;
 	my $name = _IDENTIFIER(shift)
@@ -386,7 +274,7 @@ sub add_option {
 	if ( $self->_has_state() ) {
 		PDWiX->throw('Cannot alter params once iterating');
 	}
-	if ( not $self->_option_exists($name) ) {
+	unless ( $self->_option_exists($name) ) {
 		PDWiX->throw("The dimension '$name' does not exist");
 	}
 	my $option = $self->_get_options($name);
@@ -411,8 +299,6 @@ sub _increment_state {
 	return;
 }
 
-
-
 =head2 all
 
 	my @dists = $machine->all();
@@ -422,8 +308,6 @@ distributions configured for this machine.
 
 =cut
 
-
-
 sub all {
 	my $self    = shift;
 	my @objects = ();
@@ -434,21 +318,16 @@ sub all {
 	return @objects;
 }
 
-
-
 =head2 next
 
 	my $dist = $machine->next();
 
-Returns an object that creates the next possible 
+Returns an objects that creates the next possible 
 distribution that is configured for this machine. 
 
 =cut
 
-
-
 sub next { ## no critic (ProhibitBuiltinHomonyms)
-	## no critic (ProhibitExplicitReturnUndef)
 	my $self = shift;
 	if ( $self->_get_eos() ) {
 
@@ -462,7 +341,7 @@ sub next { ## no critic (ProhibitBuiltinHomonyms)
 		# Move to the next position
 		my $found = 0;
 		foreach my $name ( $self->_get_dimensions() ) {
-			if ( $self->_get_state($name) !=
+			unless ( $self->_get_state($name) ==
 				$#{ $self->_get_options($name) } )
 			{
 
@@ -478,7 +357,7 @@ sub next { ## no critic (ProhibitBuiltinHomonyms)
 			# correct value.
 			$self->_set_state( $name => 0 );
 		} ## end foreach my $name ( $self->_get_dimensions...)
-		if ( not $found ) {
+		unless ($found) {
 			$self->_set_eos();
 			return undef;
 		}
@@ -487,7 +366,7 @@ sub next { ## no critic (ProhibitBuiltinHomonyms)
 		# Initialize to the first position
 		my %state;
 		foreach my $name ( $self->_get_dimensions() ) {
-			if ( not @{ $self->_get_options($name) } ) {
+			unless ( @{ $self->_get_options($name) } ) {
 				PDWiX->throw("No options for dimension '$name'");
 			}
 			$state{$name} = 0;
@@ -496,14 +375,12 @@ sub next { ## no critic (ProhibitBuiltinHomonyms)
 
 	} ## end else [ if ( $self->_has_state...)]
 
-	# Create the parameter-set
+	# Create the param-set
 	my @params = $self->_get_common();
 	foreach my $name ( $self->_get_dimensions() ) {
 		my $i = $self->_get_state($name);
 		push @params, @{ $self->_get_options($name)->[$i] };
 	}
-	push @params, ( '_trace_object' => $self->_get_traceobject() );
-	push @params, ( 'trace'         => $self->_get_trace() );
 
 	# Create the object with those params
 	return $self->_get_class()->new(@params);
@@ -516,8 +393,6 @@ sub next { ## no critic (ProhibitBuiltinHomonyms)
 #####################################################################
 # Execution Methods
 
-
-
 =head2 run
 
 	$machine->run();
@@ -527,8 +402,6 @@ machine.
 
 =cut
 
-
-
 sub run {
 	my $self       = shift;
 	my $success    = 0;
@@ -538,20 +411,16 @@ sub run {
 	while ( my $dist = $self->next() ) {
 		$dist->prepare();
 		$num++;
-		if ( none { $_ == $num } $self->_get_skip_values() ) {
+		if ( none { $_ == $num } $self->_get_skip_values ) {
 			$success = eval { $dist->run(); 1; };
 
 			if ($success) {
 
 				# Copy the output products for this run to the
 				# main output area.
-				foreach my $file ( $dist->get_output_files() ) {
-					File::Copy::copy( $file, $output_dir );
+				foreach my $file ( @{ $dist->output_file() } ) {
+					File::Copy::move( $file, $output_dir );
 				}
-				File::Copy::Recursive::dircopy( $dist->output_dir(),
-					catdir( $output_dir, "success-output-$num" ) );
-				File::Copy::Recursive::dircopy( $dist->fragment_dir(),
-					catdir( $output_dir, "success-fragments-$num" ) );
 			} else {
 				print $EVAL_ERROR;
 				File::Copy::Recursive::dircopy( $dist->output_dir(),
@@ -563,7 +432,7 @@ sub run {
 
 		print "\n\n\n\n\n";
 		print q{-} x 60;
-		print "\n\n\n\n\n";
+		print "\n\n\n\n\n\n";
 
 		# Flush out the image dir for the next run
 		File::Remove::remove( \1, $dist->image_dir() );
@@ -591,7 +460,7 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2009 - 2010 Curtis Jewell.
+Copyright 2009 Curtis Jewell.
 
 Copyright 2007 - 2009 Adam Kennedy.
 
